female_names = """
Mary
Patricia
Linda
Barbara
Elizabeth
Jennifer
Maria
Susan
Margaret
Dorothy
Lisa
Nancy
Karen
Betty
Helen
Sandra
Donna
Carol
Ruth
Sharon
Michelle
Laura
Sarah
Kimberly
Deborah
Jessica
Shirley
Cynthia
Angela
Melissa
Brenda
Amy
Anna
Rebecca
Virginia
Kathleen
Pamela
Martha
Debra
Amanda
Stephanie
Carolyn
Christine
Marie
Janet
Catherine
Frances
Ann
Joyce
Diane
Alice
Julie
Heather
Teresa
Doris
Gloria
Evelyn
Jean
Cheryl
Mildred
Katherine
Joan
Ashley
Judith
Rose
Janice
Kelly
Nicole
Judy
Christina
Kathy
Theresa
Beverly
Denise
Tammy
Irene
Jane
Lori
Rachel
Marilyn
Andrea
Kathryn
Louise
Sara
Anne
Jacqueline
Wanda
Bonnie
Julia
#Ruby
Lois
Tina
Phyllis
Norma
Paula
Diana
Annie
Lillian
Emily
Robin
Peggy
Crystal
Gladys
Rita
Dawn
Connie
Florence
Tracy
Edna
Tiffany
Carmen
Rosa
Cindy
Grace
Wendy
Victoria
Edith
Kim
Sherry
Sylvia
Josephine
Thelma
Shannon
Sheila
Ethel
Ellen
Elaine
Marjorie
Carrie
Charlotte
Monica
Esther
Pauline
Emma
Juanita
Anita
Rhonda
Hazel
Amber
Eva
Debbie
#April
Leslie
Clara
Lucille
Jamie
Joanne
Eleanor
Valerie
Danielle
Megan
Alicia
Suzanne
Michele
Gail
Bertha
Darlene
Veronica
Jill
Erin
Geraldine
Lauren
Cathy
Joann
Lorraine
Lynn
Sally
Regina
Erica
Beatrice
Dolores
Bernice
Audrey
Yvonne
Annette
#June
Samantha
Marion
Dana
Stacy
Ana
Renee
Ida
Vivian
Roberta
Holly
Brittany
Melanie
Loretta
Yolanda
Jeanette
Laurie
Katie
Kristen
Vanessa
Alma
Sue
Elsie
Beth
Jeanne
Vicki
Carla
Tara
Rosemary
Eileen
Terri
Gertrude
Lucy
Tonya
Ella
Stacey
Wilma
Gina
Kristin
Jessie
Natalie
Agnes
#Vera
Willie
Charlene
Bessie
Delores
Melinda
#Pearl
Arlene
Maureen
Colleen
Allison
Tamara
#Joy
Georgia
Constance
Lillie
Claudia
Jackie
Marcia
Tanya
Nellie
Minnie
Marlene
Heidi
Glenda
Lydia
Viola
Courtney
Marian
Stella
Caroline
Dora
#Jo
Vickie
Mattie
Terry
Maxine
Irma
Mabel
Marsha
Myrtle
Lena
Christy
Deanna
Patsy
Hilda
Gwendolyn
Jennie
Nora
Margie
Nina
Cassandra
Leah
Penny
#Kay
Priscilla
Naomi
Carole
Brandy
Olga
Billie
Dianne
Tracey
Leona
Jenny
Felicia
Sonia
Miriam
Velma
Becky
Bobbie
Violet
Kristina
Toni
#Misty
Mae
Shelly
Daisy
Ramona
Sherri
Erika
Katrina
Claire
Lindsey
Lindsay
Geneva
Guadalupe
Belinda
Margarita
Sheryl
Cora
Faye
#Ada
Natasha
Sabrina
Isabel
Marguerite
Hattie
Harriet
Molly
Cecilia
Kristi
Brandi
Blanche
Sandy
Rosie
Joanna
Iris
Eunice
Angie
Inez
Lynda
Madeline
Amelia
Alberta
Genevieve
Monique
Jodi
Janie
Maggie
Kayla
Sonya
Jan
Lee
Kristine
Candace
Fannie
Maryann
Opal
Alison
Yvette
Melody
Luz
Susie
Olivia
Flora
Shelley
Kristy
Mamie
Lula
Lola
Verna
Beulah
Antoinette
Candice
Juana
Jeannette
Pam
Kelli
Hannah
Whitney
Bridget
Karla
Celia
Latoya
Patty
Shelia
Gayle
Della
Vicky
Lynne
Sheri
Marianne
Kara
Jacquelyn
Erma
Blanca
Myra
Leticia
Pat
Krista
Roxanne
Angelica
Johnnie
Robyn
Francis
Adrienne
Rosalie
Alexandra
Brooke
Bethany
Sadie
Bernadette
Traci
Jody
Kendra
Jasmine
Nichole
Rachael
Chelsea
Mable
Ernestine
Muriel
Marcella
Elena
Krystal
Angelina
Nadine
Kari
Estelle
Dianna
Paulette
Lora
Mona
Doreen
Rosemarie
Angel
Desiree
Antonia
#Hope
#Ginger
Janis
Betsy
Christie
Freda
Mercedes
Meredith
Lynette
Teri
Cristina
#Eula
Leigh
Meghan
Sophia
Eloise
Rochelle
Gretchen
Cecelia
Raquel
Henrietta
Alyssa
Jana
Kelley
Gwen
Kerry
Jenna
Tricia
Laverne
#Olive
Alexis
Tasha
Silvia
Elvira
Casey
Delia
Sophie
Kate
Patti
Lorena
Kellie
Sonja
Lila
Lana
Darla
#May
Mindy
Essie
Mandy
Lorene
Elsa
Josefina
Jeannie
Miranda
Dixie
Lucia
Marta
#Faith
Lela
Johanna
Shari
Camille
Tami
Shawna
Elisa
Ebony
Melba
#Ora
Nettie
Tabitha
Ollie
Jaime
Winifred
Kristie
Marina
Alisha
Aimee
Rena
Myrna
Marla
Tammie
Latasha
Bonita
Patrice
Ronda
Sherrie
Addie
Francine
Deloris
Stacie
Adriana
Cheri
Shelby
Abigail
Celeste
#Jewel
Cara
Adele
Rebekah
Lucinda
Dorthy
Chris
Effie
Trina
Reba
Shawn
Sallie
Aurora
Lenora
Etta
Lottie
Kerri
Trisha
Nikki
Estella
Francisca
Josie
Tracie
Marissa
Karin
Brittney
Janelle
Lourdes
Laurel
Helene
Fern
Elva
Corinne
Kelsey
Ina
Bettie
Elisabeth
Aida
Caitlin
Ingrid
Iva
Eugenia
Christa
Goldie
Cassie
Maude
Jenifer
Therese
Frankie
Dena
Lorna
Janette
Latonya
Candy
Morgan
Consuelo
Tamika
Rosetta
Debora
Cherie
Polly
Dina
Jewell
Fay
Jillian
Dorothea
Nell
Trudy
Esperanza
Patrica
Kimberley
Shanna
Helena
Carolina
Cleo
Stefanie
Rosario
#Ola
Janine
Mollie
Lupe
Alisa
Lou
Maribel
Susanne
Bette
Susana
Elise
Cecile
Isabelle
Lesley
Jocelyn
Paige
Joni
Rachelle
Leola
Daphne
Alta
Ester
Petra
Graciela
Imogene
Jolene
Keisha
Lacey
Glenna
Gabriela
Keri
Ursula
Lizzie
Kirsten
Shana
Adeline
Mayra
Jayne
Jaclyn
Gracie
Sondra
Carmela
Marisa
Rosalind
Charity
Tonia
Beatriz
Marisol
Clarice
Jeanine
Sheena
Angeline
Frieda
Lily
Robbie
Shauna
Millie
Claudette
Cathleen
Angelia
Gabrielle
#Autumn
Katharine
Summer
Jodie
Staci
Lea
Christi
Jimmie
Justine
Elma
Luella
Margret
Dominique
Socorro
Rene
Martina
Margo
Mavis
Callie
Bobbi
Maritza
Lucile
Leanne
Jeannine
Deana
Aileen
Lorie
Ladonna
Willa
Manuela
Gale
Selma
Dolly
Sybil
Abby
Lara
Dale
Ivy
Dee
Winnie
Marcy
Luisa
Jeri
Magdalena
Ofelia
Meagan
Audra
Matilda
Leila
Cornelia
Bianca
Simone
Bettye
Randi
Virgie
Latisha
Barbra
Georgina
Eliza
Leann
Bridgette
Rhoda
Haley
Adela
Nola
Bernadine
Flossie
Ila
Greta
Ruthie
Nelda
Minerva
Lilly
Terrie
Letha
Hilary
Estela
Valarie
Brianna
Rosalyn
Earline
Catalina
#Ava
Mia
Clarissa
Lidia
Corrine
Alexandria
Concepcion
#Tia
Sharron
Rae
Dona
Ericka
Jami
Elnora
Chandra
Lenore
Neva
Marylou
Melisa
Tabatha
Serena
Avis
Allie
Sofia
Jeanie
Odessa
Nannie
Harriett
Loraine
Penelope
Milagros
Emilia
Benita
Allyson
Ashlee
Tania
Tommie
Esmeralda
Karina
Eve
Pearlie
Zelma
Malinda
Noreen
Tameka
Saundra
Hillary
Amie
Althea
Rosalinda
Jordan
Lilia
Alana
#Gay
Clare
Alejandra
Elinor
Michael
Lorrie
Jerri
Darcy
Earnestine
Carmella
Taylor
Noemi
Marcie
Liza
Annabelle
Louisa
Earlene
Mallory
Carlene
Nita
Selena
Tanisha
Katy
Julianne
Lakisha
Edwina
Maricela
Margery
Kenya
Dollie
Roxie
Roslyn
Kathrine
Nanette
Charmaine
Lavonne
Ilene
Kris
Tammi
Suzette
Corine
Kaye
Merle
Chrystal
Lina
Deanne
Lilian
Juliana
Aline
Luann
Kasey
Maryanne
Evangeline
Colette
Melva
Lawanda
Yesenia
Nadia
Madge
Kathie
Ophelia
Valeria
Nona
Mitzi
Mari
Georgette
Claudine
Fran
Alissa
Roseann
Lakeisha
Susanna
Reva
Deidre
Chasity
Sheree
Carly
James
Elvia
Alyce
Deirdre
Gena
Briana
Araceli
Katelyn
Rosanne
Wendi
Tessa
Berta
Marva
Imelda
Marietta
Marci
Leonor
Arline
Sasha
Madelyn
Janna
Juliette
Deena
Aurelia
Josefa
Augusta
Liliana
Young
Christian
Lessie
Amalia
Savannah
Anastasia
Vilma
Natalia
Rosella
Lynnette
Corina
Alfreda
Leanna
Carey
Amparo
Coleen
Tamra
Aisha
Wilda
Karyn
Cherry
#Queen
Maura
Mai
Evangelina
Rosanna
Hallie
Erna
Enid
Mariana
Lacy
Juliet
Jacklyn
Freida
Madeleine
Mara
Hester
Cathryn
Lelia
Casandra
Bridgett
Angelita
Jannie
Dionne
Annmarie
Katina
Beryl
Phoebe
Millicent
Katheryn
Diann
Carissa
Maryellen
Liz
Lauri
Helga
Gilda
Adrian
Rhea
Marquita
Hollie
Tisha
Tamera
Angelique
Francesca
Britney
Kaitlin
Lolita
Florine
Rowena
Reyna
Twila
Fanny
Janell
Ines
Concetta
Bertie
Alba
Brigitte
Alyson
Vonda
Pansy
Elba
Noelle
Letitia
Kitty
Deann
Brandie
Louella
Leta
Felecia
Sharlene
Lesa
Beverley
Robert
Isabella
Herminia
Terra
Celina
Tori
Octavia
Jade
Denice
Germaine
Sierra
Michell
Cortney
Nelly
Doretha
Sydney
Deidra
Monika
Lashonda
Judi
Chelsey
Antionette
Margot
Bobby
Adelaide
#Nan
Leeann
Elisha
Dessie
Libby
Kathi
Gayla
Latanya
Mina
Mellisa
Kimberlee
Jasmin
Renae
Zelda
Elda
#Ma
Justina
Gussie
Emilie
Camilla
Abbie
Rocio
Kaitlyn
Jesse
Edythe
Ashleigh
Selina
Lakesha
Geri
Allene
Pamala
Michaela
Dayna
Caryn
Rosalia
#Sun
Jacquline
Rebeca
Marybeth
Krystle
Iola
Dottie
Bennie
Belle
Aubrey
Griselda
Ernestina
Elida
Adrianne
Demetria
Delma
Chong
Jaqueline
Destiny
Arleen
Virgina
Retha
Fatima
Tillie
Eleanore
Cari
Treva
Birdie
Wilhelmina
Rosalee
Maurine
Latrice
Yong
Jena
Taryn
Elia
Debby
Maudie
Jeanna
Delilah
Catrina
Shonda
Hortencia
Theodora
Teresita
Robbin
Danette
Maryjane
Freddie
Delphine
Brianne
Nilda
Danna
Cindi
Bess
Iona
Hanna
Ariel
Winona
Vida
Rosita
Marianna
William
Racheal
Guillermina
Eloisa
Celestine
Caren
Malissa
Lona
Chantel
Shellie
Marisela
Leora
Agatha
Soledad
Migdalia
Ivette
Christen
Athena
Janel
Chloe
Veda
Pattie
Tessie
Tera
Marilynn
Lucretia
Karrie
Dinah
Daniela
Alecia
Adelina
Vernice
Shiela
Portia
#Merry
Lashawn
Devon
Dara
Tawana
#Oma
Verda
Christin
Alene
Zella
Sandi
Rafaela
Maya
Kira
Candida
Alvina
Suzan
Shayla
Lyn
Lettie
Alva
Samatha
Oralia
Matilde
Madonna
Larissa
Vesta
Renita
#India
Delois
Shanda
Phillis
Lorri
Erlinda
Cruz
Cathrine
Barb
Zoe
Isabell
Ione
Gisela
Charlie
Valencia
Roxanna
Mayme
Kisha
Ellie
Mellissa
Dorris
Dalia
Bella
Annetta
Zoila
Reta
Reina
Lauretta
Kylie
Christal
Pilar
Charla
Elissa
Tiffani
Tana
Paulina
Leota
Breanna
Jayme
Carmel
Vernell
Tomasa
Mandi
Dominga
Santa
Melodie
Lura
Alexa
Tamela
Ryan
Mirna
Kerrie
Venus
Noel
Felicita
Cristy
Carmelita
Berniece
Annemarie
Tiara
Roseanne
Missy
Cori
Roxana
Pricilla
Kristal
Jung
Elyse
Haydee
Aletha
Bettina
Marge
Gillian
Filomena
Charles
Zenaida
Harriette
Caridad
#Vada
#Una
Aretha
Pearline
Marjory
Marcela
Flor
Evette
Elouise
Alina
Trinidad
David
Damaris
Catharine
Carroll
Belva
Nakia
Marlena
Luanne
Lorine
Karon
Dorene
Danita
Brenna
Tatiana
Sammie
Louann
Loren
Julianna
Andria
Philomena
Lucila
Leonora
Dovie
Romona
Mimi
Jacquelin
Gaye
Tonja
Misti
Joe
Gene
Chastity
Stacia
Roxann
Micaela
Nikita
#Mei
Velda
Marlys
Johnna
Aura
Lavern
Ivonne
Hayley
Nicki
Majorie
Herlinda
George
Alpha
Yadira
Perla
Gregoria
Daniel
Antonette
Shelli
Mozelle
Mariah
Joelle
Cordelia
Josette
Chiquita
Trista
Louis
Laquita
Georgiana
Candi
Shanon
Lonnie
Hildegard
Cecil
Valentina
Stephany
Magda
Karol
Gerry
Gabriella
Tiana
Roma
Richelle
Ray
Oleta
Jacque
Idella
Alaina
Suzanna
Jovita
Blair
Tosha
Raven
Nereida
Marlyn
Kyla
Joseph
Delfina
Tena
Stephenie
Sabina
Nathalie
Marcelle
Gertie
Darleen
Thea
Sharonda
Shantel
Belen
Venessa
Rosalina
Genoveva
Corey
Clementine
Rosalba
Renate
Renata
Ivory
Georgianna
Floy
Dorcas
Ariana
Tyra
Theda
Mariam
Juli
Jesica
Donnie
Vikki
Verla
Roselyn
Melvina
Jannette
Ginny
Debrah
Corrie
Asia
Violeta
Myrtis
Latricia
Collette
Charleen
Anissa
Viviana
Twyla
Precious
Nedra
Latonia
#Lan
Hellen
Fabiola
Annamarie
Adell
Sharyn
Chantal
Niki
Maud
Lizette
Lindy
#Kia
Kesha
Jeana
Danelle
Charline
Chanel
Carrol
Valorie
#Lia
Dortha
Cristal
#Sunny
Leone
Leilani
Gerri
Debi
Andra
Keshia
#Ima
Eulalia
Easter
Dulce
Natividad
Linnie
Kami
Georgie
Catina
Brook
Alda
Winnifred
Sharla
Ruthann
Meaghan
Magdalene
Lissette
Adelaida
Venita
Trena
Shirlene
Shameka
Elizebeth
Dian
Shanta
Mickey
Latosha
Carlotta
#Windy
#Soon
Rosina
Mariann
Leisa
Jonnie
Dawna
Cathie
Billy
Astrid
Sidney
Laureen
Janeen
Holli
Fawn
Vickey
Teressa
Shante
Rubye
Marcelina
Chanda
Cary
Terese
Scarlett
Marty
Marnie
Lulu
Lisette
Jeniffer
Elenor
Dorinda
Donita
Carman
Bernita
Altagracia
Aleta
Adrianna
Zoraida
Ronnie
Nicola
Lyndsey
Kendall
Janina
Chrissy
#Ami
Starla
Phylis
Phuong
Kyra
Charisse
Blanch
Sanjuanita
Rona
Nanci
Marilee
Maranda
Cory
Brigette
Sanjuana
Marita
Kassandra
Joycelyn
Ira
Felipa
Chelsie
Bonny
Mireya
Lorenza
Kyong
Ileana
Candelaria
Tony
Toby
Sherie
#Ok
Mark
Lucie
Leatrice
Lakeshia
Gerda
Edie
Bambi
Marylin
Lavon
Hortense
Garnet
Evie
Tressa
Shayna
Lavina
Kyung
Jeanetta
Sherrill
Shara
Phyliss
Mittie
Anabel
Alesia
Thuy
Tawanda
Richard
Joanie
Tiffanie
Lashanda
Karissa
Enriqueta
Daria
Daniella
Corinna
Alanna
Abbey
Roxane
Roseanna
Magnolia
Lida
Kyle
Joellen
#Era
#Coral
Carleen
Tresa
Peggie
Novella
Nila
Maybelle
Jenelle
Carina
#Nova
Melina
Marquerite
Margarette
Josephina
Evonne
Devin
Cinthia
Albina
Toya
Tawnya
Sherita
Santos
Myriam
Lizabeth
Lise
Keely
Jenni
Giselle
Cheryle
Ardith
Ardis
Alesha
Adriane
Shaina
Linnea
Karolyn
Hong
Florida
Felisha
Dori
Darci
Artie
Armida
Zola
Xiomara
Vergie
Shamika
Nena
Nannette
Maxie
Lovie
Jeane
Jaimie
Inge
Farrah
Elaina
Caitlyn
Starr
Felicitas
Cherly
Caryl
Yolonda
Yasmin
Teena
Prudence
Pennie
Nydia
Mackenzie
Orpha
Marvel
Lizbeth
Laurette
Jerrie
Hermelinda
Carolee
Tierra
Mirian
Meta
Melony
Kori
Jennette
Jamila
#Ena
#Anh
Yoshiko
Susannah
Salina
Rhiannon
Joleen
Cristine
Ashton
Aracely
Tomeka
Shalonda
Marti
Lacie
Kala
Jada
Ilse
Hailey
Brittani
Zona
Syble
Sherryl
Randy
Nidia
Marlo
Kandice
Kandi
Deb
Dean
#America
Alycia
Tommy
Ronna
Norene
Mercy
Jose
Ingeborg
Giovanna
Gemma
Christel
Audry
Zora
#Vita
#Van
Trish
Stephaine
Shirlee
Shanika
Melonie
Mazie
Jazmin
Inga
#Hoa
Hettie
Geralyn
Fonda
Estrella
Adella
#Su
Sarita
Rina
Milissa
Maribeth
Golda
Evon
Ethelyn
Enedina
Cherise
Chana
Velva
Tawanna
Sade
Mirta
Li
Karie
Jacinta
Elna
Davina
Cierra
Ashlie
Albertha
Tanesha
Stephani
Nelle
Mindi
Lu
Lorinda
Larue
Florene
Demetra
Dedra
Ciara
Chantelle
Ashly
Suzy
Rosalva
Noelia
Lyda
Leatha
Krystyna
Kristan
Karri
Darline
Darcie
Cinda
Cheyenne
Cherrie
Awilda
Almeda
Rolanda
Lanette
Jerilyn
Gisele
Evalyn
Cyndi
Cleta
Carin
Zina
Zena
Velia
Tanika
Paul
Charissa
Thomas
Talia
Margarete
Lavonda
Kaylee
Kathlene
Jonna
Irena
Ilona
Idalia
Candis
Candance
Brandee
Anitra
Alida
Sigrid
Nicolette
Maryjo
Linette
Hedwig
Christiana
Cassidy
Alexia
Tressie
Modesta
Lupita
Lita
Gladis
Evelia
Davida
Cherri
Cecily
Ashely
Annabel
Agustina
Wanita
Shirly
Rosaura
Hulda
#Eun
Bailey
Yetta
Verona
Thomasina
Sibyl
Shannan
Mechelle
#Lue
Leandra
Lani
Kylee
Kandy
Jolynn
Ferne
Eboni
Corene
Alysia
Zula
Nada
Moira
Lyndsay
Lorretta
Juan
Jammie
Hortensia
Gaynell
Cameron
Adria
#Vina
Vicenta
Tangela
Stephine
Norine
Nella
Liana
Leslee
Kimberely
Iliana
#Glory
Felica
Emogene
Elfriede
Eden
Eartha
Carma
Bea
Ocie
Marry
Lennie
Kiara
Jacalyn
Carlota
Arielle
Yu
#Star
Otilia
Kirstin
Kacey
Johnetta
Joey
Joetta
Jeraldine
Jaunita
Elana
Dorthea
Cami
Amada
Adelia
Vernita
Tamar
Siobhan
Renea
Rashida
Ouida
Odell
Nilsa
Meryl
Kristyn
Julieta
Danica
Breanne
Aurea
Anglea
Sherron
Odette
Malia
Lorelei
Lin
Leesa
Kenna
Kathlyn
Fiona
Charlette
Suzie
Shantell
Sabra
Racquel
Myong
Mira
Martine
Lucienne
Lavada
Juliann
Johnie
Elvera
Delphia
Clair
Christiane
Charolette
Carri
Augustine
Asha
Angella
Paola
Ninfa
#Leda
#Lai
#Eda
#Sunshine
Stefani
Shanell
Palma
Machelle
Lissa
Kecia
Kathryne
Karlene
Julissa
Jettie
Jenniffer
#Hui
Corrina
Christopher
Carolann
Alena
Tess
Rosaria
Myrtice
Marylee
Liane
Kenyatta
Judie
Janey
#In
Elmira
Eldora
Denna
Cristi
Cathi
Zaida
Vonnie
Viva
Vernie
Rosaline
Mariela
Luciana
Lesli
Karan
Felice
Deneen
Adina
Wynona
Tarsha
Sheron
Shasta
Shanita
Shani
Shandra
Randa
Pinkie
Paris
Nelida
Marilou
Lyla
Laurene
Laci
Joi
Janene
Dorotha
Daniele
Dani
Carolynn
Carlyn
Berenice
Ayesha
Anneliese
Alethea
Thersa
Tamiko
Rufina
Oliva
Mozell
Marylyn
Madison
Kristian
Kathyrn
Kasandra
Kandace
Janae
Gabriel
Domenica
Debbra
Dannielle
Chun
Buffy
Barbie
Arcelia
Aja
Zenobia
Sharen
Sharee
Patrick
#Page
#My
Lavinia
Kum
Kacie
Jackeline
Huong
Felisa
Emelia
Eleanora
Cythia
Cristin
Clyde
Claribel
Caron
Anastacia
Zulma
Zandra
Yoko
Tenisha
Susann
Sherilyn
Shay
Shawanda
Sabine
Romana
Mathilda
Linsey
Keiko
Joana
Isela
Gretta
Georgetta
Eugenie
Dusty
Desirae
Delora
Corazon
Antonina
Anika
Willene
Tracee
Tamatha
Regan
Nichelle
Mickie
Maegan
Luana
Lanita
Kelsie
Edelmira
Bree
Afton
Teodora
Tamie
Shena
Meg
Linh
Keli
Kaci
Danyelle
Britt
Arlette
Albertine
Adelle
Tiffiny
Stormy
Simona
#Numbers
Nicolasa
Nichol
#Nia
Nakisha
Mee
Maira
Loreen
Kizzy
Johnny
Jay
Fallon
Christene
Bobbye
Anthony
Ying
Vincenza
Tanja
Rubie
Roni
Queenie
Margarett
Kimberli
Irmgard
Idell
Hilma
Evelina
#Esta
Emilee
Dennise
Dania
Carl
Carie
Antonio
Wai
Sang
Risa
Rikki
Particia
Mui
Masako
Mario
Luvenia
Loree
Loni
Lien
Kevin
Gigi
Florencia
Dorian
Denita
Dallas
#Chi
Billye
Alexander
Tomika
Sharita
Rana
Nikole
Neoma
Margarite
Madalyn
Lucina
Laila
Kali
Jenette
Gabriele
Evelyne
Elenora
Clementina
Alejandrina
Zulema
Violette
Vannessa
Thresa
Retta
#Pia
Patience
Noella
Nickie
Jonell
#Delta
Chung
Chaya
Camelia
Bethel
Anya
Andrew
Thanh
Suzann
Spring
Shu
Mila
Lilla
Laverna
Keesha
Kattie
Gia
Georgene
Eveline
Estell
Elizbeth
Vivienne
Vallie
Trudie
Stephane
Michel
Magaly
Madie
Kenyetta
Karren
Janetta
Hermine
Harmony
Drucilla
Debbi
Celestina
Candie
Britni
Beckie
Amina
Zita
Yun
Yolande
Vivien
Vernetta
Trudi
Sommer
Pearle
Patrina
Ossie
Nicolle
Loyce
Letty
Larisa
Katharina
Joselyn
Jonelle
Jenell
Iesha
Heide
Florinda
Florentina
Flo
Elodia
Dorine
Brunilda
Brigid
Ashli
Ardella
Twana
Thu
Tarah
Sung
Shea
Shavon
Shane
Serina
Rayna
Ramonita
#Nga
Margurite
Lucrecia
Kourtney
Kati
Jesus
Jesenia
Diamond
Crista
Ayana
Alica
Alia
Vinnie
Suellen
Romelia
Rachell
Piper
Olympia
Michiko
Kathaleen
Jolie
Jessi
Janessa
Hana
#Ha
Elease
Carletta
Britany
Shona
Salome
Rosamond
Regena
Raina
Ngoc
Nelia
Louvenia
Lesia
Latrina
Laticia
Larhonda
Jina
Jacki
Hollis
Holley
Emmy
Deeann
Coretta
Arnetta
#Velvet
Thalia
Shanice
Neta
Mikki
Micki
Lonna
Leana
Lashunda
Kiley
Joye
Jacqulyn
Ignacia
Hyun
Hiroko
Henry
Henriette
Elayne
Delinda
Darnell
Dahlia
Coreen
Consuela
Conchita
Celine
Babette
Ayanna
Anette
Albertina
Skye
Shawnee
Shaneka
Quiana
Pamelia
#Min
Merri
Merlene
Margit
Kiesha
Kiera
Kaylene
Jodee
Jenise
Erlene
Emmie
#Else
Daryl
Dalila
Daisey
Cody
Casie
Belia
Babara
Versie
Vanesa
Shelba
Shawnda
Sam
Norman
Nikia
Naoma
Marna
Margeret
Madaline
Lawana
Kindra
Jutta
Jazmine
Janett
Hannelore
Glendora
Gertrud
Garnett
Freeda
Frederica
Florance
Flavia
Dennis
Carline
Beverlee
Anjanette
Valda
Trinity
Tamala
Stevie
Shonna
#Sha
Sarina
Oneida
Micah
Merilyn
Marleen
Lurline
Lenna
Katherin
Jin
Jeni
#Hae
Gracia
Glady
Farah
Eric
Enola
Ema
Dominque
Devona
Delana
Cecila
Caprice
Alysha
Ali
Alethia
Vena
Theresia
Tawny
#Song
Shakira
Samara
Sachiko
Rachele
Pamella
Nicky
Marni
Mariel
Maren
Malisa
Ligia
Lera
Latoria
Larae
Kimber
Kathern
Karey
Jennefer
Janeth
Halina
Fredia
Delisa
Debroah
Ciera
Chin
Angelika
Andree
Altha
Yen
Vivan
Terresa
Tanna
Suk
Sudie
Soo
Signe
Salena
Ronni
Rebbecca
Myrtie
Mckenzie
Malika
Maida
#Loan
Leonarda
Kayleigh
France
Ethyl
Ellyn
Dayle
Cammie
Brittni
Birgit
Avelina
Asuncion
Arianna
Akiko
Venice
Tyesha
Tonie
Tiesha
Takisha
Steffanie
Sindy
Santana
Meghann
Manda
Macie
#Lady
Kellye
Kellee
Joslyn
Jason
Inger
Indira
Glinda
Glennis
Fernanda
Faustina
Eneida
Elicia
#Dot
#Digna
#Dell
Arletta
Andre
Willia
Tammara
Tabetha
Sherrell
Sari
Refugio
Rebbeca
Pauletta
Nieves
Natosha
Nakita
Mammie
Kenisha
Kazuko
Kassie
Gary
Earlean
Daphine
Corliss
Clotilde
Carolyne
Bernetta
Augustina
Audrea
Annis
Annabell
Yan
Tennille
Tamica
Selene
Sean
Rosana
Regenia
Qiana
Markita
Macy
Leeanne
Laurine
Kym
Jessenia
Janita
Georgine
Genie
Emiko
Elvie
Deandra
Dagmar
Corie
Collen
Cherish
Romaine
Porsha
Pearlene
Micheline
Merna
Margorie
Margaretta
Lore
Kenneth
Jenine
Hermina
Fredericka
Elke
Drusilla
Dorathy
Dione
Desire
Celena
Brigida
Angeles
Allegra
Theo
Tamekia
Synthia
Stephen
Sook
Slyvia
Rosann
Reatha
Raye
Marquetta
Margart
Ling
Layla
Kymberly
Kiana
Kayleen
Katlyn
Karmen
Joella
Irina
Emelda
Eleni
Detra
Clemmie
Cheryll
Chantell
Cathey
Arnita
Arla
#Angle
Angelic
Alyse
Zofia
Thomasine
Tennie
#Son
Sherly
Sherley
Sharyl
Remedios
Petrina
Nickole
Myung
Myrle
Mozella
Louanne
Lisha
Latia
#Lane
Krysta
Julienne
Joel
Jeanene
Jacqualine
Isaura
Gwenda
Earleen
Donald
Cleopatra
Carlie
Audie
Antonietta
Alise
Alex
Verdell
#Val
Tyler
Tomoko
Thao
Talisha
Steven
#So
Shemika
Shaun
Scarlet
Savanna
Santina
Rosia
Raeann
Odilia
Nana
Minna
Magan
Lynelle
#Le
#Karma
Joeann
Ivana
Inell
Ilana
Hye
#Honey
Hee
Gudrun
Frank
Dreama
Crissy
Chante
Carmelina
Arvilla
Arthur
Annamae
Alvera
Aleida
Aaron
Yee
Yanira
Vanda
Tianna
Tam
Stefania
Shira
Perry
Nicol
Nancie
Monserrate
Minh
Melynda
Melany
Matthew
Lovella
Laure
Kirby
Kacy
Jacquelynn
Hyon
Gertha
Francisco
Eliana
Christena
Christeen
Charise
Caterina
Carley
Candyce
Arlena
Ammie
Yang
Willette
Vanita
Tuyet
#Tiny
Syreeta
Silva
Scott
Ronald
Penney
Nyla
Michal
Maurice
Maryam
Marya
Magen
Ludie
Loma
Livia
Lanell
Kimberlie
Julee
Donetta
Diedra
Denisha
Deane
Dawne
Clarine
Cherryl
Bronwyn
Brandon
Alla
Valery
Tonda
Sueann
Soraya
Shoshana
Shela
Sharleen
Shanelle
Nerissa
Micheal
Meridith
Mellie
#Maye
#Maple
Magaret
Luis
Lili
Leonila
Leonie
Leeanna
Lavonia
Lavera
Kristel
Kathey
Kathe
Justin
Julian
Jimmy
Jann
Ilda
Hildred
Hildegarde
Genia
Fumiko
Evelin
Ermelinda
Elly
Dung
Doloris
Dionna
Danae
Berneice
Annice
Alix
Verena
Verdie
Tristan
Shawnna
Shawana
Shaunna
Rozella
Randee
Ranae
Milagro
Lynell
Luise
Louie
Loida
Lisbeth
Karleen
Junita
Jona
Isis
Hyacinth
Hedy
Gwenn
Ethelene
Erline
Edward
Donya
Domonique
Delicia
Dannette
Cicely
Branda
Blythe
Bethann
Ashlyn
Annalee
Alline
Yuko
Vella
Trang
Towanda
Tesha
Sherlyn
Narcisa
Miguelina
Meri
Maybell
Marlana
Marguerita
Madlyn
Luna
Lory
Loriann
Liberty
Leonore
Leighann
Laurice
Latesha
Laronda
Katrice
Kasie
Karl
Kaley
Jadwiga
Glennie
Gearldine
Francina
Epifania
Dyan
Dorie
Diedre
Denese
Demetrice
Delena
Darby
Cristie
Cleora
Catarina
Carisa
Bernie
Barbera
Almeta
Trula
Tereasa
Solange
Sheilah
Shavonne
Sanora
Rochell
Mathilde
Margareta
Maia
Lynsey
Lawanna
Launa
Kena
Keena
Katia
Jamey
Glynda
Gaylene
Elvina
Elanor
Danuta
Danika
Cristen
Cordie
Coletta
Clarita
Carmon
Brynn
Azucena
Aundrea
Angele
Yi
Walter
Verlie
Verlene
Tamesha
Silvana
Sebrina
Samira
Reda
Raylene
Penni
Pandora
Norah
Noma
Mireille
Melissia
Maryalice
Laraine
Kimbery
Karyl
Karine
Kam
Jolanda
Johana
Jesusa
Jaleesa
Jae
Jacquelyne
Irish
Iluminada
Hilaria
Hanh
Gennie
Francie
Floretta
Exie
Edda
Drema
Delpha
Bev
Barbar
Assunta
Ardell
Annalisa
Alisia
Yukiko
Yolando
Wonda
Wei
Waltraud
Veta
Tequila
Temeka
Tameika
Shirleen
Shenita
Piedad
Ozella
Mirtha
Marilu
Kimiko
Juliane
Jenice
Jen
Janay
Jacquiline
Hilde
#Fe
Fae
Evan
Eugene
Elois
#Echo
Devorah
Chau
Brinda
Betsey
Arminda
Aracelis
Apryl
Annett
Alishia
Veola
Usha
Toshiko
Theola
Tashia
Talitha
Shery
Rudy
Renetta
Reiko
Rasheeda
#Omega
Obdulia
Mika
Melaine
Meggan
Martin
Marlen
Marget
Marceline
Mana
Magdalen
Librada
Lezlie
Lexie
Latashia
Lasandra
Kelle
Isidra
#Isa
Inocencia
Gwyn
Francoise
Erminia
Erinn
Dimple
Devora
Criselda
Armanda
Arie
Ariane
Angelo
Angelena
Allen
Aliza
Adriene
Adaline
Xochitl
Twanna
Tran
Tomiko
Tamisha
Taisha
Susy
Siu
Rutha
Roxy
Rhona
Raymond
Otha
Noriko
Natashia
Merrie
Melvin
Marinda
Mariko
Margert
Loris
Lizzette
Leisha
Kaila
#Ka
Joannie
Jerrica
Jene
Jannet
Janee
Jacinda
Herta
Elenore
Doretta
Delaine
Daniell
Claudie
#China
Britta
Apolonia
Amberly
Alease
Yuri
Yuk
Wen
Waneta
Ute
Tomi
Sharri
Sandie
Roselle
Reynalda
Raguel
Phylicia
Patria
Olimpia
Odelia
Mitzie
Mitchell
Miss
Minda
Mignon
Mica
Mendy
Marivel
Maile
Lynetta
Lavette
Lauryn
Latrisha
Lakiesha
Kiersten
Kary
Josphine
Jolyn
Jetta
Janise
Jacquie
Ivelisse
Glynis
Gianna
Gaynelle
#Emerald
Demetrius
Danyell
Danille
Dacia
Coralee
Cher
Ceola
Brett
#Bell
Arianne
Aleshia
Yung
Williemae
Troy
Trinh
Thora
Tai
Svetlana
Sherika
Shemeka
Shaunda
Roseline
Ricki
Melda
Mallie
Lavonna
Latina
Larry
Laquanda
Lala
Lachelle
Klara
Kandis
Johna
Jeanmarie
Jaye
Hang
Grayce
Gertude
Emerita
Ebonie
Clorinda
Ching
Chery
Carola
Breann
Blossom
Bernardine
Becki
Arletha
Argelia
#Ara
Alita
Yulanda
Yon
Yessenia
Tobi
Tasia
Sylvie
Shirl
Shirely
Sheridan
Shella
Shantelle
Sacha
Royce
Rebecka
Reagan
Providencia
Paulene
Misha
Miki
Marline
Marica
Lorita
Latoyia
Lasonya
Kerstin
Kenda
Keitha
Kathrin
Jaymie
Jack
Gricelda
Ginette
Eryn
Elina
Elfrieda
Danyel
Cheree
Chanelle
Barrie
Avery
Aurore
Annamaria
Alleen
Ailene
Aide
Yasmine
Vashti
Valentine
Treasa
Tory
Tiffaney
Sheryll
Sharie
Shanae
Sau
Raisa
#Pa
Neda
Mitsuko
Mirella
Milda
Maryanna
Maragret
Mabelle
Luetta
Lorina
Letisha
Latarsha
Lanelle
Lajuana
Krissy
Karly
Karena
Jon
Jessika
Jerica
Jeanelle
January
Jalisa
Jacelyn
Izola
Ivey
Gregory
Euna
Etha
Drew
Domitila
Dominica
Daina
Creola
Carli
Camie
Bunny
Brittny
Ashanti
Anisha
Aleen
Adah
Yasuko
Winter
Viki
Valrie
Tona
Tinisha
#Thi
Terisa
Tatum
Taneka
Simonne
Shalanda
Serita
Ressie
Refugia
#Paz
Olene
#Na
Merrill
Margherita
Mandie
#Man
Maire
Lyndia
Luci
Lorriane
Loreta
Leonia
Lavona
Lashawnda
Lakia
Kyoko
Krystina
Krysten
Kenia
Kelsi
Jude
Jeanice
Isobel
Georgiann
Genny
Felicidad
Eilene
Deon
Deloise
Deedee
Dannie
#Conception
Clora
Cherilyn
Chang
Calandra
Berry
Armandina
Anisa
Ula
Timothy
Tiera
Theressa
Stephania
Sima
Shyla
Shonta
Shera
Shaquita
Shala
Sammy
Rossana
Nohemi
Nery
Moriah
Melita
Melida
Melani
Marylynn
Marisha
Mariette
Malorie
Madelene
Ludivina
Loria
Lorette
Loralee
Lianne
Leon
Lavenia
Laurinda
Lashon
#Kit
Kimi
Keila
Katelynn
Kai
Jone
Joane
#Ji
Jayna
Janella
#Ja
#Hue
Hertha
Francene
Elinore
Despina
Delsie
Deedra
Clemencia
Carry
Carolin
Carlos
Bulah
Brittanie
#Bok
Blondell
Bibi
Beaulah
Beata
Annita
Agripina
Virgen
Valene
#Un
Twanda
Tommye
Toi
Tarra
Tari
Tammera
Shakia
Sadye
Ruthanne
Rochel
Rivka
Pura
Nenita
Natisha
Ming
Merrilee
Melodee
Marvis
Lucilla
Leena
Laveta
Larita
Lanie
Keren
Ileen
Georgeann
Genna
Genesis
Frida
Ewa
Eufemia
Emely
Ela
Edyth
Deonna
Deadra
Darlena
Chanell
Chan
Cathern
Cassondra
Cassaundra
Bernarda
Berna
Arlinda
Anamaria
Albert
Wesley
Vertie
Valeri
Torri
Tatyana
Stasia
Sherise
Sherill
Season
Scottie
Sanda
Ruthe
Rosy
Roberto
Robbi
Ranee
Quyen
Pearly
Palmira
Onita
Nisha
Niesha
Nida
#Nevada
#Nam
Merlyn
Mayola
Marylouise
Maryland
Marx
Marth
Margene
Madelaine
Londa
Leontine
Leoma
Leia
Lawrence
Lauralee
Lanora
Lakita
Kiyoko
Keturah
Katelin
Kareen
Jonie
Johnette
Jenee
Jeanett
Izetta
Hiedi
Heike
Hassie
Harold
Giuseppina
Georgann
Fidela
Fernande
Elwanda
Ellamae
Eliz
Dusti
Dotty
Cyndy
Coralie
Celesta
Argentina
Alverta
Xenia
Wava
Vanetta
Torrie
Tashina
Tandy
Tambra
Tama
Stepanie
Shila
Shaunta
Sharan
Shaniqua
Shae
Setsuko
Serafina
Sandee
Rosamaria
Priscila
Olinda
Nadene
#Muoi
Michelina
Mercedez
Maryrose
Marin
Marcene
#Mao
Magali
Mafalda
Logan
Linn
Lannie
Kayce
Karoline
Kamilah
Kamala
Justa
Joline
Jennine
Jacquetta
Iraida
Gerald
Georgeanna
Franchesca
#Fairy
Emeline
Elane
Ehtel
Earlie
Dulcie
Dalene
Cris
Classie
Chere
Charis
Caroyln
Carmina
Carita
Brian
Bethanie
Ayako
Arica
#An
Alysa
Alessandra
Akilah
Adrien
Zetta
Youlanda
Yelena
Yahaira
Xuan
Wendolyn
Victor
Tijuana
Terrell
Terina
Teresia
Suzi
Sunday
Sherell
Shavonda
Shaunte
Sharda
Shakita
Sena
Ryann
Rubi
Riva
Reginia
Rea
Rachal
Parthenia
Pamula
Monnie
Monet
Michaele
Melia
Marine
Malka
Maisha
Lisandra
Leo
Lekisha
Lean
Laurence
Lakendra
Krystin
Kortney
Kizzie
Kittie
Kera
Kendal
Kemberly
Kanisha
Julene
Jule
Joshua
Johanne
Jeffrey
Jamee
Han
Halley
Gidget
Galina
Fredricka
Fleta
Fatimah
Eusebia
Elza
Eleonore
Dorthey
Doria
Donella
Dinorah
Delorse
Claretha
Christinia
Charlyn
Bong
Belkis
Azzie
Andera
Aiko
Adena
#Yer
Yajaira
#Wan
Vania
Ulrike
Toshia
Tifany
Stefany
Shizue
Shenika
Shawanna
Sharolyn
Sharilyn
Shaquana
Shantay
#See
Rozanne
Roselee
Rickie
Remona
Reanna
Raelene
Quinn
Phung
Petronila
Natacha
Nancey
Myrl
Miyoko
Miesha
Merideth
Marvella
Marquitta
Marhta
Marchelle
Lizeth
Libbie
Lahoma
Ladawn
Kina
Katheleen
Katharyn
Karisa
Kaleigh
Junie
Julieann
Johnsie
Janean
Jaimee
Jackqueline
Hisako
Herma
Helaine
Gwyneth
Glenn
#Gita
Eustolia
Emelina
#Elin
Edris
Donnette
Donnetta
Dierdre
Denae
Darcel
Claude
Clarisa
Cinderella
Chia
Charlesetta
Charita
Celsa
Cassy
Cassi
Carlee
Bruna
Brittaney
Brande
Billi
Bao
Antonetta
Angla
Angelyn
Analisa
Alane
Wenona
Wendie
Veronique
Vannesa
Tobie
Tempie
Sumiko
Sulema
#Sparkle
Somer
Sheba
Shayne
Sharice
Shanel
Shalon
Sage
Roy
Rosio
Roselia
Renay
Rema
Reena
#Porsche
Ping
Peg
Ozie
Oretha
Oralee
Oda
#Nu
Ngan
Nakesha
Milly
Marybelle
Marlin
Maris
Margrett
Maragaret
Manie
Lurlene
Lillia
Lieselotte
Lavelle
Lashaunda
Lakeesha
Keith
Kaycee
Kalyn
Joya
Joette
Jenae
Janiece
Illa
Grisel
Glayds
Genevie
Gala
Fredda
Fred
Elmer
Eleonor
Debera
Deandrea
Dan
Corrinne
Cordia
Contessa
Colene
Cleotilde
Charlott
Chantay
Cecille
Beatris
Azalee
Arlean
Ardath
Anjelica
Anja
Alfredia
Aleisha
Adam
Zada
Yuonne
Xiao
Willodean
Whitley
Vennie
Vanna
Tyisha
Tova
Torie
Tonisha
Tilda
Tien
#Temple
Sirena
Sherril
Shanti
Shan
Senaida
Samella
Robbyn
Renda
Reita
Phebe
Paulita
Nobuko
Nguyet
Neomi
#Moon
Mikaela
Melania
Maximina
Marg
Maisie
Lynna
Lilli
Layne
Lashaun
Lakenya
Lael
Kirstie
Kathline
Kasha
Karlyn
Karima
Jovan
Josefine
Jennell
Jacqui
Jackelyn
Hyo
Hien
Grazyna
Florrie
Floria
Eleonora
Dwana
Dorla
Dong
#Delmy
#Deja
#Dede
Dann
Crysta
Clelia
Claris
Clarence
Chieko
Cherlyn
Cherelle
Charmain
Chara
Cammy
#Bee
Arnette
Ardelle
Annika
Amiee
Amee
Allena
Yvone
Yuki
Yoshie
Yevette
Yael
Willetta
Voncile
Venetta
Tula
Tonette
Timika
Temika
Telma
Teisha
Taren
#Ta
Stacee
Shin
Shawnta
Saturnina
Ricarda
#Pok
#Pasty
Onie
Nubia
Mora
Mike
Marielle
Mariella
Marianela
Mardell
#Many
Luanna
Loise
Lisabeth
Lindsy
Lilliana
Lilliam
Lelah
Leigha
Leanora
Lang
Kristeen
Khalilah
Keeley
Kandra
Junko
Joaquina
Jerlene
Jani
Jamika
Jame
Hsiu
Hermila
Golden
Genevive
Evia
Eugena
Emmaline
Elfreda
Elene
Donette
Delcie
Deeanna
Darcey
#Cuc
Clarinda
Cira
Chae
Celinda
Catheryn
Catherin
Casimira
Carmelia
Camellia
Breana
Bobette
Bernardina
#Bebe
Basilia
Arlyne
Amal
Alayna
Zonia
Zenia
Yuriko
Yaeko
Wynell
#Willow
Willena
Vernia
#Tu
Travis
Tora
Terrilyn
Terica
Tenesha
Tawna
Tajuana
Taina
Stephnie
#Sona
#Sol
Sina
Shondra
Shizuko
Sherlene
Sherice
Sharika
Rossie
Rosena
Rory
Rima
Ria
Rheba
Renna
Peter
Natalya
Nancee
Melodi
Meda
Maxima
Matha
Marketta
Maricruz
Marcelene
Malvina
Luba
Louetta
Leida
Lecia
Lauran
Lashawna
Laine
Khadijah
Katerine
Kasi
Kallie
Julietta
Jesusita
Jestine
Jessia
Jeremy
Jeffie
Janyce
Isadora
Georgianne
Fidelia
Evita
Eura
Eulah
Estefana
Elsy
Elizabet
Eladia
Dodie
Dion
#Dia
Denisse
Deloras
Delila
Daysi
Dakota
Curtis
Crystle
Concha
Colby
Claretta
#Chu
Christia
Charlsie
Charlena
Carylon
Bettyann
Asley
Ashlea
Amira
#Ai
Agueda
Agnus
Yuette
Vinita
Victorina
Tynisha
Treena
Toccara
Tish
Thomasena
Tegan
Soila
Shiloh
Shenna
Sharmaine
Shantae
Shandi
#September
Saran
Sarai
Sana
Samuel
Salley
Rosette
Rolande
Regine
Otelia
Oscar
Olevia
Nicholle
Necole
Naida
Myrta
Myesha
Mitsue
Minta
Mertie
Margy
Mahalia
Madalene
#Love
Loura
Lorean
Lewis
Lesha
Leonida
Lenita
Lavone
Lashell
Lashandra
Lamonica
Kimbra
Katherina
Karry
Kanesha
Julio
Jong
Jeneva
Jaquelyn
Hwa
Gilma
Ghislaine
Gertrudis
Fransisca
Fermina
Ettie
Etsuko
Ellis
Ellan
Elidia
Edra
Dorethea
Doreatha
Denyse
Denny
Deetta
Daine
Cyrstal
Corrin
Cayla
Carlita
Camila
Burma
Bula
Buena
Blake
Barabara
Avril
Austin
Alaine
Zana
Wilhemina
Wanetta
Virgil
#Vi
Veronika
Vernon
Verline
Vasiliki
Tonita
Tisa
Teofila
Tayna
Taunya
Tandra
Takako
Sunni
Suanne
Sixta
Sharell
Seema
Russell
Rosenda
Robena
Raymonde
Pei
Pamila
Ozell
Neida
Neely
Mistie
Micha
Merissa
Maurita
Maryln
Maryetta
Marshall
Marcell
Malena
Makeda
Maddie
Lovetta
Lourie
Lorrine
Lorilee
Lester
Laurena
Lashay
Larraine
Laree
Lacresha
Kristle
Krishna
Keva
Keira
Karole
Joie
Jinny
Jeannetta
Jama
Heidy
Gilberte
Gema
Faviola
Evelynn
Enda
Elli
Ellena
Divina
Dagny
Collene
Codi
Cindie
Chassidy
Chasidy
Catrice
Catherina
Cassey
Caroll
Carlena
Candra
Calista
Bryanna
Britteny
Beula
Bari
Audrie
Audria
Ardelia
Annelle
Angila
Alona
Allyn
"""



if __name__ == '__main__':
    names = map(str.strip, female_names.split())

    with file('/home/timv/projects/python-extras/nlp/lexicon/english-words.txt','r') as f:
        words = frozenset(map(str.strip, f.xreadlines()))
        
        print 'loaded %s words' % len(words)
        print 'loaded %s names' % len(names)

        for name in names:
            if name.lower() in words:
                print name




import sys
import time
from threading import Thread
from functools import wraps

# TODO: add verbose argument to timelimit and retry

class dispatch(Thread):
    def __init__(self, f, *args, **kwargs):
        Thread.__init__(self)
        self.f = f
        self.args = args
        self.kwargs = kwargs
        self.result = None
        self.error = None
        self.setDaemon(True)
        self.start()
    def run(self):
        try:
            self.result = self.f(*self.args, **self.kwargs)
        except:
            # store exception information in the thread.
            self.error = sys.exc_info()

class TimeoutError(Exception):
    pass

def timelimit(timeout):
    """
    A decorator to limit a function to `timeout` seconds, raising TimeoutError
    if it takes longer.

        >>> def meaningoflife():
        ...     time.sleep(.2)
        ...     return 42
        >>>
        >>> timelimit(.1)(meaningoflife)()
        Traceback (most recent call last):
            ...
        TimeoutError: took too long
        >>> timelimit(1)(meaningoflife)()
        42

    _Caveat:_ The function isn't stopped after `timeout` seconds but continues
    executing in a separate thread. (There seems to be no way to kill a thread)
    inspired by
        <http://aspn.activestate.com/ASPN/Cookbook/Python/Recipe/473878>
    """
    def _1(f):
        @wraps(f)
        def _2(*args, **kwargs):
            c = dispatch(f, *args, **kwargs)
            c.join(timeout)
            if c.isAlive():
                raise TimeoutError('took too long')
            if c.error:
                raise c.error[1]
            return c.result
        return _2
    return _1

#_______________________________________________________________________________
#

def retry_apply(fn, args, kwargs=None, tries=2, pause=0.1, suppress=(Exception,),
                allow=(NameError, NotImplementedError)):
    """
    Attempt to call `fn` up to `tries` times with the `args` as arguments

    `suppress`: exceptions to be ignored up to the last retry-attempt.
    `allow`:    exceptions which will not be suppressed; this helps avoid
                stupid mistakes such as NameErrors and NotImplementedErrors.
    """
    if kwargs is None:
        kwargs = {}
    for i in xrange(tries):
        try:
            return fn(*args, **kwargs)
        except allow:          # raise these exceptions
            raise
        except suppress:
            if i == tries - 1:  # the last iteration
                raise
        time.sleep(pause)


def retry(tries=2, pause=0.1, suppress=(Exception,), allow=(NameError, NotImplementedError)):
    def retry1(f):
        @wraps(f)
        def retry2(*args, **kw):
            return retry_apply(f, args, kw, tries=tries, pause=pause, suppress=suppress, allow=allow)
        return retry2
    return retry1


if __name__ == '__main__':
    from testing.assertions import assert_throws

    def test_retry():

        class NotCalledEnough(Exception): pass
        class TroublsomeFunction(object):
            "Function-like object which must be called >=4 times before succeeding."
            def __init__(self):
                self.tries = 0
            def __call__(self, *args):
                self.tries += 1
                if self.tries > 4:
                    return True
                else:
                    raise NotCalledEnough

        f = TroublsomeFunction()
        assert retry_apply(f, (1,2,3), tries=5)
        assert f.tries == 5

        with assert_throws(NotCalledEnough):
            f = TroublsomeFunction()
            print retry_apply(f, (10,), tries=2)


        def create_trouble(tries_needs, attempts):
            calls = []
            @retry(tries=attempts, pause=0.0)
            def troublesome(a, kw=None):
                "I'm a troublesome function!"
                assert a == 'A' and kw == 'KW'
                calls.append(1)
                if len(calls) < tries_needs:
                    raise NotCalledEnough
                else:
                    return 'the secret'
            assert troublesome.__doc__ == "I'm a troublesome function!"
            assert troublesome.__name__ == 'troublesome'
            troublesome('A', kw='KW')

        create_trouble(4, 4)

        with assert_throws(NotCalledEnough):
            create_trouble(4, 2)


        @retry(tries=4, pause=0.0)
        def broken_function():
            raise NotImplementedError

        with assert_throws(NotImplementedError):
            broken_function()


    def test_timed():

        @timelimit(1.0)
        def sleepy_function(x): time.sleep(x)

        with assert_throws(TimeoutError):
            sleepy_function(3.0)

        sleepy_function(0.2)

        @timelimit(1)
        def raises_errors(): return 1/0
        with assert_throws(ZeroDivisionError):
            raises_errors()

    test_retry()
    test_timed()

    import doctest
    doctest.testmod()

    print 'passed tests..'



import os
from arsenal.fsutils import mkdir, secure_filename
from arsenal.robust import timelimit, retry
from arsenal.misc import ignore_error
from urllib2 import Request, build_opener


def urlread(url):
    req_headers = {
        'User-Agent': 'Mozilla/5.0 (Windows; U; Windows NT 5.1; en-US)'
                      ' AppleWebKit/525.13 (KHTML, like Gecko)'
                      ' Chrome/0.A.B.C Safari/525.13',
        'Referer': 'http://python.org'
    }

    request = Request(url, headers=req_headers)
    response = build_opener().open(request)

    code = response.code
    headers = response.headers
    contents = response.read()
    return code, headers, contents


#from functools import wraps
#
# TODO: use this decorator in download... and test it...
#def cached_to_file(args2filename):
#    """
#    Decorator to cache output of function to file. If file exists contents are
#    returned and function is never called.
#    """
#
#    def _f1(fn):
#
#        @wraps(fn)
#        def _f2(*args, **kwargs):
#
#            filename = args2filename(*args, **kwargs)
#
#            if os.path.exists(filename):
#                return file(filename).read()
#
#            val = fn(*args, **kwargs)
#
#            try:
#                with file(filename, 'wb') as f:
#                    f.write(val)
#            except:
#                try:
#                    os.remove(filename)
#                except OSError:
#                    pass
#
#        return _f2
#
#    return _f1


def download(url, usecache=True, cached=None, cachedir='cache~/', cachedonly=False, **opts):
    """
    Download (or cache) ``url`` to file. On success: return file name of stored
    contents. Upon failure: return None.

    Will retry ``tries`` times with ``pause`` seconds between each attempt to
    download.

    Download will timeout after ``timeout`` seconds.

    If ``cachedonly`` is enabled, this function will not download anything. It
    will simply return the cached filename if it exists.
    """

    if not cached:
        if cachedir:
            mkdir(cachedir)
            cached = os.path.join(cachedir, secure_filename(url))
        else:
            assert not usecache, 'must specify cachedir'

    # only return something for cached files
    if cachedonly and not os.path.exists(cached):
        return

    if usecache and os.path.exists(cached):
        return cached

    # use wget for ftp files
    if url.startswith('ftp'):
        return wget(url, cached)

    if url.startswith('http'):
        return robust_download(url, cached, **opts)


def wget(url, filename):
    """
    Wraps call to wget to download ``url`` to ``filename``.
    """
    retcode = os.system("wget '%s' -O '%s'" % (url, filename))
    if retcode != 0:
        if os.path.exists(filename):
            os.remove(filename)
            return
    return filename


def robust_download(url, filename, tries=3, pause=0.1, timeout=30, verbose=True):
    """
    Attempts ``tries`` times to download and write contents ``url`` to
    ``filename``. Will timeout after ``timeout`` seconds.

    returns ``None`` upon failure and ``filename`` on success.
    """

    if verbose:
        print 'trying to download %s to file://%s' % (url, filename)

    @retry(tries=tries, pause=pause)
    @timelimit(timeout=timeout)
    def _download():
        with file(filename, 'wb') as f:
            [code, _, contents] = urlread(url)
            assert code == 200
            f.write(contents)
            return filename

    result = None
    with ignore_error():
        result =_download()

    # delete file on failure
    if not result:
        if verbose: print '  failed to download'
        if os.path.exists(filename):
            if verbose: print '  deleting file'
            os.remove(filename)
        return
    else:
        if verbose: print '  download successful'
        return filename


if __name__ == '__main__':
    download('http://timvieira.github.com', cachedir='/tmp/')



#!/usr/bin/env python

#****************************************************************************
# unitatom.py, provides class to hold data on each available unit
#
# ConvertAll, a units conversion program
# Copyright (C) 2006, Douglas W. Bell
#
# This is free software; you can redistribute it and/or modify it under the
# terms of the GNU General Public License, Version 2.  This program is
# distributed in the hope that it will be useful, but WITTHOUT ANY WARRANTY.
#*****************************************************************************

import re, copy
import unitdata


class UnitAtom:
    """Reads and stores a single unit conversion"""
    partialExp = 1000
    badOpRegEx = re.compile(r'[^\d\.eE\+\-\*/]')
    eqnRegEx = re.compile(r'\[(.*?)\](.*)')
    def __init__(self, dataStr):
        dataList = dataStr.split('#')
        unitList = dataList.pop(0).split('=', 1)
        self.name = unitList.pop(0).strip()
        self.equiv = ''
        self.factor = 1.0
        self.fromEqn = ''   # used only for non-linear units
        self.toEqn = ''     # used only for non-linear units
        if unitList:
            self.equiv = unitList[0].strip()
            if self.equiv[0] == '[':   # used only for non-linear units
                try:
                    self.equiv, self.fromEqn = UnitAtom.eqnRegEx.\
                                               match(self.equiv).groups()
                    if ';' in self.fromEqn:
                        self.fromEqn, self.toEqn = self.fromEqn.split(';', 1)
                        self.toEqn = self.toEqn.strip()
                    self.fromEqn = self.fromEqn.strip()
                except AttributeError:
                    raise unitdata.UnitDataError, \
                          'Bad equation for "%s"' % self.name
            else:                # split factor and equiv unit for linear
                parts = self.equiv.split(None, 1)
                if len(parts) > 1 and \
                         UnitAtom.badOpRegEx.search(parts[0]) == None:
                                      # only allowed digits and operators
                    try:
                        self.factor = float(eval(parts[0]))
                        self.equiv = parts[1]
                    except:
                        pass
        self.comments = [comm.strip() for comm in dataList]
        self.comments.extend([''] * (2 - len(self.comments)))
        self.exp = 1
        self.viewLink = [None, None]
        self.typeName = ''

    def description(self):
        """Return name and 1st comment (usu. full name) if applicable"""
        if self.comments[0]:
            return '%s  (%s)' % (self.name, self.comments[0])
        return self.name

    def unitValid(self):
        """Return True if unit and exponent are valid"""
        if self.equiv and \
                -UnitAtom.partialExp < self.exp < UnitAtom.partialExp:
            return True
        return False

    def unitText(self, absExp=False):
        """Return text for unit name with exponent or absolute value of exp"""
        exp = self.exp
        if absExp:
            exp = abs(self.exp)
        if exp == 1:
            return self.name
        if -UnitAtom.partialExp < exp < UnitAtom.partialExp:
            return '%s^%d' % (self.name, exp)
        if exp > 1:
            return '%s^' % self.name
        else:
            return '%s^-' % self.name

    def matchWords(self, wordList):
        """Return True if unit name and comments match word list"""
        dataStr = ' '.join((self.name, self.comments[0], \
                            self.comments[1])).lower()
        for word in wordList:
            if dataStr.find(word) == -1:
                return False
        return True

    def copy(self):
        """Retrun a copy of the unit so the exponent can be changed"""
        return copy.copy(self)

    def __cmp__(self, other):
        return cmp(self.name.lower(), other.name.lower())



#Copyright (c) 2009 Eugene Kaznacheev <qetzal@gmail.com>

#Permission is hereby granted, free of charge, to any person
#obtaining a copy of this software and associated documentation
#files (the "Software"), to deal in the Software without
#restriction, including without limitation the rights to use,
#copy, modify, merge, publish, distribute, sublicense, and/or sell
#copies of the Software, and to permit persons to whom the
#Software is furnished to do so, subject to the following
#conditions:

#The above copyright notice and this permission notice shall be
#included in all copies or substantial portions of the Software.

#THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
#EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES
#OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
#NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
#HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
#WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
#FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
#OTHER DEALINGS IN THE SOFTWARE.

"""
Fetches weather reports from Google Weather, Yahoo Wheather and NOAA
"""

import urllib2, string
from xml.dom import minidom

GOOGLE_WEATHER_URL = 'http://www.google.com/ig/api?weather=%s&hl=%s'
YAHOO_WEATHER_URL = 'http://xml.weather.yahoo.com/forecastrss?p=%s&u=%s'
YAHOO_WEATHER_NS = 'http://xml.weather.yahoo.com/ns/rss/1.0'
NOAA_WEATHER_URL = 'http://www.weather.gov/xml/current_obs/%s.xml'

def get_weather_from_google(location_id, hl = ''):
    """
    Fetches weather report from Google

    Parameters 
      location_id: a zip code (10001); city name, state (weather=woodland,PA); city name, country (weather=london,england); or possibly others.
      hl: the language parameter (language code)

    Returns:
      weather_data: a dictionary of weather data that exists in XML feed. 
    """

    url = GOOGLE_WEATHER_URL % (location_id, hl)
    handler = urllib2.urlopen(url)
    dom = minidom.parse(handler)    
    handler.close()

    weather_data = {}
    weather_dom = dom.getElementsByTagName('weather')[0]

    data_structure = { 
        'forecast_information': ('city', 'postal_code', 'latitude_e6', 'longitude_e6', 'forecast_date', 'current_date_time', 'unit_system'),
        'current_conditions': ('condition','temp_f', 'temp_c', 'humidity', 'wind_condition', 'icon')
    }           
    for (tag, list_of_tags2) in data_structure.iteritems():
        tmp_conditions = {}
        for tag2 in list_of_tags2:
            tmp_conditions[tag2] =  weather_dom.getElementsByTagName(tag)[0].getElementsByTagName(tag2)[0].getAttribute('data')
        weather_data[tag] = tmp_conditions

    forecast_conditions = ('day_of_week', 'low', 'high', 'icon', 'condition')
    forecasts = []
    
    for forecast in dom.getElementsByTagName('forecast_conditions'):
        tmp_forecast = {}
        for tag in forecast_conditions:
            tmp_forecast[tag] = forecast.getElementsByTagName(tag)[0].getAttribute('data')
        forecasts.append(tmp_forecast)

    weather_data['forecasts'] = forecasts    
    dom.unlink()

    return weather_data
    


def get_weather_from_yahoo(location_id, units = 'metric'):
    """
    Fetches weather report from Yahoo!

    Parameters 
    location_id: A five digit US zip code or location ID. To find your location ID, 
    browse or search for your city from the Weather home page(http://weather.yahoo.com/)
    The weather ID is in the URL for the forecast page for that city. You can also get the location ID by entering your zip code on the home page. For example, if you search for Los Angeles on the Weather home page, the forecast page for that city is http://weather.yahoo.com/forecast/USCA0638.html. The location ID is USCA0638.

    units: type of units. 'metric' for metric and '' for  non-metric
    Note that choosing metric units changes all the weather units to metric, for example, wind speed will be reported as kilometers per hour and barometric pressure as millibars.
 
    Returns:
    weather_data: a dictionary of weather data that exists in XML feed. See  http://developer.yahoo.com/weather/#channel
    """

    if units == 'metric':
        unit = 'c'
    else:
        unit = 'f'
    url = YAHOO_WEATHER_URL % (location_id, unit)
    handler = urllib2.urlopen(url)
    dom = minidom.parse(handler)    
    handler.close()
        
    weather_data = {}
    weather_data['title'] = dom.getElementsByTagName('title')[0].firstChild.data
    weather_data['link'] = dom.getElementsByTagName('link')[0].firstChild.data

    ns_data_structure = { 
        'location': ('city', 'region', 'country'),
        'units': ('temperature', 'distance', 'pressure', 'speed'),
        'wind': ('chill', 'direction', 'speed'),
        'atmosphere': ('humidity', 'visibility', 'pressure', 'rising'),
        'astronomy': ('sunrise', 'sunset'),
        'condition': ('text', 'code', 'temp', 'date')
    }       
    
    for (tag, attrs) in ns_data_structure.iteritems():
        weather_data[tag] = xml_get_ns_yahoo_tag(dom, YAHOO_WEATHER_NS, tag, attrs)

    weather_data['geo'] = {}
    weather_data['geo']['lat'] = dom.getElementsByTagName('geo:lat')[0].firstChild.data
    weather_data['geo']['long'] = dom.getElementsByTagName('geo:long')[0].firstChild.data

    weather_data['condition']['title'] = dom.getElementsByTagName('item')[0].getElementsByTagName('title')[0].firstChild.data
    weather_data['html_description'] = dom.getElementsByTagName('item')[0].getElementsByTagName('description')[0].firstChild.data
    
    forecasts = []
    for forecast in dom.getElementsByTagNameNS(YAHOO_WEATHER_NS, 'forecast'):
        forecasts.append(xml_get_attrs(forecast,('date', 'low', 'high', 'text', 'code')))
    weather_data['forecasts'] = forecasts
    
    dom.unlink()

    return weather_data

    
    
def get_weather_from_noaa(station_id):
    """
    Fetches weather report from NOAA: National Oceanic and Atmospheric Administration (United States)

    Parameter:
    station_id: the ID of the weather station near the necessary location
    To find your station ID, perform the following steps:
    1. Open this URL: http://www.weather.gov/xml/current_obs/seek.php?state=az&Find=Find
    2. Select the necessary state state. Click 'Find'.
    3. Find the necessary station in the 'Observation Location' column.
    4. The station ID is in the URL for the weather page for that station.
    For example if the weather page is http://weather.noaa.gov/weather/current/KPEO.html -- the station ID is KPEO.

    Other way to get the station ID: use this library: http://code.google.com/p/python-weather/ and 'Weather.location2station' function.

    Returns:
    weather_data: a dictionary of weather data that exists in XML feed. 

    (useful icons: http://www.weather.gov/xml/current_obs/weather.php)
    """

    url = NOAA_WEATHER_URL % (station_id)
    handler = urllib2.urlopen(url)
    dom = minidom.parse(handler)    
    handler.close()
        
    data_structure = ('suggested_pickup',
                'suggested_pickup_period',
                'location',
                'station_id',
                'latitude',
                'longitude',
                'observation_time',
                'observation_time_rfc822',
                'weather',
                'temperature_string',
                'temp_f',
                'temp_c',
                'relative_humidity',
                'wind_string',
                'wind_dir',
                'wind_degrees',
                'wind_mph',
                'wind_gust_mph',
                'pressure_string',
                'pressure_mb',
                'pressure_in',
                'dewpoint_string',
                'dewpoint_f',
                'dewpoint_c',
                'heat_index_string',
                'heat_index_f',
                'heat_index_c',
                'windchill_string',
                'windchill_f',
                'windchill_c',
                'icon_url_base',
                'icon_url_name',
                'two_day_history_url',
                'ob_url'
                )
    weather_data = {}
    current_observation = dom.getElementsByTagName('current_observation')[0]
    for tag in data_structure:
        try:
            weather_data[tag] = current_observation.getElementsByTagName(tag)[0].firstChild.data
        except IndexError:
            pass

    dom.unlink()
    return weather_data


    
def xml_get_ns_yahoo_tag(dom, YAHOO_WEATHER_NS, tag, attrs):
    """
    Parses the necessary tag and returns the dictionary with values
    
    Parameters:
    dom - DOM
    YAHOO_WEATHER_NS - namespace
    tag - necessary tag
    attrs - tuple of attributes

    Returns: a dictionary of elements 
    """
    element = dom.getElementsByTagNameNS(YAHOO_WEATHER_NS, tag)[0]
    return xml_get_attrs(element,attrs)


def xml_get_attrs(xml_element, attrs):
    """
    Returns the list of necessary attributes
    
    Parameters: 
    element: xml element
    attrs: tuple of attributes

    Return: a dictionary of elements
    """
    
    result = {}
    for attr in attrs:
        result[attr] = xml_element.getAttribute(attr)   
    return result



if __name__ == '__main__':
    import sys
    for k,v in get_weather_from_google(*sys.argv[1:])['current_conditions'].iteritems():
        print '%20s => %s' % (k,v)



scientific_units = """
kg
kilogram
key
hectogram
dekagram
gram
g
decigram
centigram
milligram
mg
microgram
tonne
metric ton
megagram
kilotonne
gigagram
teragram
carat
ct
amu
atomic mass unit
pound
lb
lbm
ounce
oz
lid
ton
kiloton
slug
stone
grain
m
meter
metre
decimeter
cm
centimeter
mm
millimeter
micrometer
micron
nanometer
nm
dekameter
hectometer
km
kilometer
megameter
angstrom
fermi
inch
in
inches
mil
microinch
microinches
foot
ft
feet
yard
yd
mile
mi
nautical mile
nmi
league
chain
fathom
rod
furlong
hand
cubit
point
pica
caliber
football field
marathon
au
astronomical unit
light year
light minute
light second
parsec
kiloparsec
megaparsec
screw size
AWG
American Wire Gauge
standard gauge
zinc gauge
ring size
shoe size mens
shoe size womens
s
sec
second
ms
millisecond
microsecond
ns
nanosecond
minute
min
hour
hr
bell
watch
watches
day
week
wk
fortnight
month
year
yr
calendar year
decade
century
centuries
millennium
millennia
man hour
man week
man month
man year
K
Kelvin
deg K
degree Kelvin
C
Celsius
deg C
degree Celsius
R
Rankine
deg R
F
Fahrenheit
deg F
degree Fahrenheit
C deg
Celsius degree
F deg
Fahrenheit degree
A
ampere
amp
milliampere
milliamp
mA
microampere
kiloampere
kA
coulomb
amp hour
mAh
milliamp hour
volt
V
millivolt
mV
kilovolt
kV
ohm
milliohm
microhm
kilohm
siemens
farad
millifarad
microfarad
nanofarad
picofarad
weber
Wb
henry
H
millihenry
mH
microhenry
tesla
T
mol
mole
gram mole
kilomole
kmol
pound mole
lbmol
avogadro
cd
candela
lumen
lm
lux
footcandle
metercandle
lambert
millilambert
footlambert
radian
rad
circle
turn
revolution
rev
degree
deg
arc min
arc minute
min arc
minute arc
arc sec
arc second
sec arc
second arc
quadrant
right angle
gradian
sr
steradian
sphere
hemisphere
bit
kilobit
byte
B
kilobyte
kB
megabyte
MB
gigabyte
GB
terabyte
TB
petabyte
PB
kibibyte
KiB
mebibyte
MiB
gibibyte
GiB
tebibyte
TiB
pebibyte
PiB
bps
kbps
unit
1
pi
pair
hat trick
dozen
doz
bakers dozen
score
gross
great gross
ream
percent
%
mill
APR
proof
ppm
parts per million
ppb
parts per billion
ppt
parts per trillion
karat
carat gold
newton
N
dekanewton
kilonewton
kN
meganewton
millinewton
dyne
kg force
kgf
kilogram force
gram force
pound force
lbf
ton force
ounce force
ozf
barn
are
decare
dekare
hectare
acre
section
township
homestead
circular inch
circular mil
cc
cubic centimeter
liter
l
litre
deciliter
centiliter
milliliter
ml
dekaliter
hectoliter
kiloliter
kl
megaliter
gallon
gal
quart
qt
pint
pt
fluid ounce
fl oz
ounce fluid
imperial gallon
imp gal
imperial quart
imp qt
imperial pint
imp pt
imperial fluid ounce
imp fl oz
cup
tablespoon
tbsp
teaspoon
tsp
barrel
bbl
shot
fifth
wine bottle
magnum
keg
bushel
peck
cord
board foot
board feet
knot
kt
light speed
mph
kph
mach
rpm
rps
gph
gpm
cfs
cfm
lpm
sccm
sccs
slpm
slph
scfh
scfm
Pa
pascal
kPa
kilopascal
MPa
megapascal
atm
atmosphere
bar
mbar
millibar
microbar
decibar
kilobar
mm Hg
millimeter of Hg
torr
in Hg
inch of Hg
m water
m H2O
meter of water
in water
in H2O
inch of water
ft water
ft H2O
feet of water
foot of head
ft hd
psi
pound per sq inch
ksi
density water
density sea water
density Hg
density air
density steel
density aluminum
density zinc
density brass
density copper
density iron
density nickel
density tin
density titanium
density silver
density nylon
density polycarbonate
joule
J
kilojoule
kJ
megajoule
gigajoule
millijoule
mJ
calorie
cal
kilocalorie
kcal
calorie food
Btu
British thermal unit
erg
electronvolt
eV
kWh
kilowatt hour
ton TNT
watt
W
kilowatt
kW
megawatt
MW
gigawatt
GW
milliwatt
horsepower
hp
metric horsepower
hertz
Hz
millihertz
kilohertz
kHz
megahertz
MHz
gigahertz
GHz
becquerel
Bq
curie
millicurie
roentgen
gray
Gy
rad. abs. dose
sievert
millisievert
Sv
rem
millirem
poise
P
centipoise
cP
stokes
St
centistokes
cSt
gravity
gravity constant
gas constant
mpg
"""



#!/usr/bin/env python
#
#  Look up any area codes listed on the command-line.
#
#  Slapped together by Sean Reifschneider, <jafo-areacode@tummy.com>
#  Placed into the public domain, 2000-10-17

ACDict = {
    '201' : 'Hackensack/Jersey City, NJ',
    '202' : 'Washington D.C.',
    '203' : 'New Haven, Stamford, southwestern CT',
    '204' : 'Manitoba',
    '205' : 'Central Alabama',
    '206' : 'Seattle, WA',
    '207' : 'Maine',
    '208' : 'Idaho',
    '209' : 'Modesto/Stockton, CA',
    '210' : 'San Antonio, TX',
    '212' : 'Manhattan, NY',
    '213' : 'Los Angeles, CA',
    '214' : 'Dallas, TX',
    '215' : 'Philadelphia, PA',
    '216' : 'Cleveland, OH',
    '217' : 'Champaign/Springfield, IL',
    '218' : 'Northern Minnesota',
    '219' : 'Northern Indiana',
    '224' : 'Chicago, IL',
    '225' : 'Baton Rouge, LA',
    '228' : 'Mississippi Gulf Coast',
    '240' : 'Maryland (DC Suburbs)',
    '242' : 'Bahamas',
    '246' : 'Barbados',
    '248' : 'Detroit, MI',
    '250' : 'Vancouver Island, BC',
    '252' : 'North Carolina Coast',
    '253' : 'Tacoma, WA',
    '254' : 'Waco, TX',
    '256' : 'Northern Alabama',
    '264' : 'Anguilla',
    '267' : 'Philadelphia, PA',
    '268' : 'Antigua, Barbuda',
    '270' : 'Western Kentucky',
    '281' : 'Houston, TX',
    '284' : 'British Virgin Islands',
    '301' : 'Maryland DC Suburbs',
    '302' : 'Delaware',
    '303' : 'Denver, CO',
    '304' : 'West Virginia',
    '305' : 'Miami, FL',
    '306' : 'Saskatchewan',
    '307' : 'Wyoming',
    '308' : 'Western Nebraska',
    '309' : 'West Central Illinois',
    '310' : 'Los Angeles, CA',
    '312' : 'Chicago, IL',
    '313' : 'Detroit, MI',
    '314' : 'St. Louis, MO',
    '315' : 'North Central NY',
    '316' : 'Southern Kansas',
    '317' : 'Indianapolis, IN',
    '318' : 'Northern Louisiana',
    '319' : 'Eastern Iowa',
    '320' : 'West Central Minnesota',
    '323' : 'Los Angeles, CA',
    '330' : 'Akron/Canton, OH',
    '334' : 'Southern Alabama',
    '336' : 'Greensboro, NC',
    '340' : 'US Virgin Islands',
    '345' : 'Cayman Islands',
    '347' : 'New York City',
    '352' : 'Gainesville/Ocala, FL',
    '360' : 'Southwestern Washington',
    '401' : 'Rhode Island',
    '402' : 'Eastern Nebraska',
    '403' : 'Alberta',
    '404' : 'Atlanta, GA',
    '405' : 'Western Oklahoma',
    '406' : 'Montana',
    '407' : 'Orlando, FL',
    '408' : 'San Jose, CA',
    '409' : 'Southeast Texas',
    '410' : 'Baltimore, MD',
    '412' : 'Pittsburgh, PA',
    '413' : 'Western Massachusetts',
    '414' : 'Milwaukee, WI',
    '415' : 'Marin County, CA',
    '416' : 'Toronto, ON',
    '417' : 'Southwestern Missouri',
    '418' : 'Eastern Quebec',
    '419' : 'Northwestern Ohio',
    '423' : 'Eastern Tennessee',
    '424' : 'Los Angeles, CA',
    '425' : 'Redmond, WA',
    '435' : 'Utah',
    '440' : 'Cleveland, OH',
    '441' : 'Bermuda',
    '443' : 'Baltimore, MD',
    '450' : 'Montreal Suburbs',
    '473' : 'Grenada',
    '484' : 'Allentown, PA',
    '501' : 'Central/Northwestern Arkansas',
    '502' : 'Western Kentucky',
    '503' : 'Northwestern Oregon',
    '504' : 'New Orleans, LA',
    '505' : 'New Mexico',
    '506' : 'New Brunswick',
    '507' : 'Southern Minnesota',
    '508' : 'Southeastern Massachusetts',
    '509' : 'Eastern Washington',
    '510' : 'Oakland, CA',
    '512' : 'Austin/Corpus Christi, TX',
    '513' : 'Cincinnati, OH',
    '514' : 'Montreal, PQ',
    '515' : 'Central Iowa',
    '516' : 'Long Island, NY',
    '517' : 'Lansing/Saginaw, MI',
    '518' : 'Northeastern New York',
    '519' : 'Ontario Panhandle',
    '520' : 'Arizona',
    '530' : 'Northeastern California',
    '540' : 'Western Viginia',
    '541' : 'Oregon',
    '559' : 'Fresno, CA',
    '561' : 'East Central Florida',
    '562' : 'Los Angeles, CA',
    '570' : 'Scranton, PA',
    '573' : 'Central Missouri',
    '580' : 'Nortwestern Oklahoma',
    '601' : 'Mississippi',
    '602' : 'Phoenix, AZ',
    '603' : 'New Hampshire',
    '604' : 'Vancouver, BC',
    '605' : 'South Dakota',
    '606' : 'Eastern Kentucky',
    '607' : 'South Central New York',
    '608' : 'Southwestern Wisconsin',
    '609' : 'Southern New Jersey',
    '610' : 'Allentown, PA',
    '612' : 'Minneapolis, MN',
    '613' : 'Ottawa, ON',
    '614' : 'Columbus, OH',
    '615' : 'Nashville, TN',
    '616' : 'Western Michigan',
    '617' : 'Boston, MA',
    '618' : 'Southern Illinois',
    '619' : 'San Diego, CA',
    '626' : 'Los Angeles, CA',
    '630' : 'Chicago Suburbs, IL',
    '646' : 'New York City',
    '649' : 'Turks & Caicos Islands',
    '650' : 'San Francisco, CA',
    '651' : 'St. Paul,MN',
    '660' : 'North Central Missouri',
    '661' : 'Los Angeles, CA',
    '664' : 'Montserrat',
    '670' : 'Northern Mariana Islands',
    '671' : 'Guam',
    '678' : 'Atlanta, GA',
    '701' : 'North Dakota',
    '702' : 'Las Vegas, NV',
    '703' : 'Arlington, VA',
    '704' : 'Charlotte, NC',
    '705' : 'North Central Ontario',
    '706' : 'Northern Georgia',
    '707' : 'Northwestern California',
    '708' : 'Chicago Suburbs, IL',
    '709' : 'Newfoundland',
    '712' : 'Western Iowa',
    '713' : 'Houston, TX',
    '714' : 'Anaheim, CA',
    '715' : 'Northern Wisconsin',
    '716' : 'Western New York',
    '717' : 'Harrisburg, PA',
    '718' : 'New York City',
    '719' : 'Southeastern Colorado',
    '720' : 'Denver, CO',
    '724' : 'Western Pennsylvania',
    '727' : 'St. Petersburg, FL',
    '732' : 'Northern Jersey Shore region',
    '734' : 'Detroit, MI',
    '740' : 'Southeastern Ohio',
    '757' : 'Norfolk, VA',
    '758' : 'St. Lucia',
    '760' : 'Southeastern California',
    '765' : 'Lafayette/Muncie IL',
    '767' : 'Dominica',
    '770' : 'Atlanta, GA',
    '773' : 'Chicago, IL',
    '775' : 'Nevada',
    '780' : 'Northern Alberta',
    '781' : 'Boston, MA',
    '784' : 'St. Vincent & the Grenadines',
    '784' : 'Northwestern Kansas',
    '786' : 'Miami, FL',
    '787' : 'Puerto Rico',
    '801' : 'Salt Lake City, UT',
    '802' : 'Vermont',
    '803' : 'Central South Carolina',
    '804' : 'Richmond, VA',
    '805' : 'Oxnard, CA',
    '806' : 'Texas Panhandle',
    '807' : 'Northwestern Ontario',
    '808' : 'Hawaii',
    '809' : 'Dominican Republic',
    '810' : 'Detroit, MI',
    '812' : 'Southern Indiana',
    '813' : 'Tampa, FL',
    '814' : 'Altoona/Erie, PA',
    '815' : 'Northern Illinois',
    '816' : 'Kansas City, MO',
    '817' : 'Ft. Worth, TC',
    '818' : 'San Fernando, CA',
    '819' : 'Quebec',
    '828' : 'Asheville, NC',
    '830' : 'San Antonio, TX',
    '831' : 'Monterey, CA',
    '843' : 'Coastal South Carolina',
    '847' : 'Chicago, IL',
    '850' : 'Florida Panhandle',
    '858' : 'San Diego, CA',
    '860' : 'Northern Connecticut',
    '864' : 'Northwestern South Carolina',
    '867' : 'The Great Frozen North of Canada',
    '868' : 'Trinidad & Tobago',
    '869' : "St. Kitt's & Nevis",
    '870' : 'Eastern Arkansas',
    '876' : 'Jamaica',
    '901' : 'Western Tennessee',
    '902' : 'Nova Scotia',
    '903' : 'Northeastern Texas',
    '904' : 'Northeastern Florida',
    '905' : 'Toronto, ON',
    '906' : 'UP Michigan',
    '907' : 'Alaska',
    '908' : 'Elizabeth, NJ',
    '909' : 'San Bernardino, CA',
    '910' : 'Southeastern North Carolina',
    '912' : 'Southern Georgia',
    '913' : 'Kansas City, KS',
    '914' : 'New York City',
    '915' : 'Western Texas',
    '916' : 'Sacramento, CA',
    '917' : 'New York City Wireless',
    '918' : 'Northeastern Oklahoma',
    '919' : 'Raleigh, NC',
    '920' : 'Northeastern Wisconsin',
    '925' : 'Concord, CA',
    '931' : 'Central Tennessee',
    '935' : 'San Diego, CA',
    '937' : 'Dayton, OH',
    '940' : 'Wichita Falls, TX',
    '941' : 'Southwestern Florida',
    '949' : 'Irvine, CA',
    '954' : 'Broward County, FL',
    '956' : 'Brownsville/Laredo, TX',
    '970' : 'Colorado Western Slope',
    '972' : 'Dallas, TX',
    '973' : 'Newark, NJ',
    '978' : 'Northeastern Massachusetts',
}

if __name__ == '__main__':
    import sys
    for arg in sys.argv[1:]:
        print '%s is %s' % ( arg, ACDict.get(arg, '(Unknown)') )






from opcode import opmap, HAVE_ARGUMENT, EXTENDED_ARG
globals().update(opmap)

def _make_constants(f, builtin_only=False, stoplist=[], verbose=False):
    try:
        co = f.func_code
    except AttributeError:
        return f        # Jython doesn't have a func_code attribute.
    newcode = map(ord, co.co_code)
    newconsts = list(co.co_consts)
    names = co.co_names
    codelen = len(newcode)

    import __builtin__
    env = vars(__builtin__).copy()
    if builtin_only:
        stoplist = dict.fromkeys(stoplist)
        stoplist.update(f.func_globals)
    else:
        env.update(f.func_globals)

    # First pass converts global lookups into constants
    i = 0
    while i < codelen:
        opcode = newcode[i]
        if opcode in (EXTENDED_ARG, STORE_GLOBAL):
            return f    # for simplicity, only optimize common cases
        if opcode == LOAD_GLOBAL:
            oparg = newcode[i+1] + (newcode[i+2] << 8)
            name = co.co_names[oparg]
            if name in env and name not in stoplist:
                value = env[name]
                for pos, v in enumerate(newconsts):
                    if v is value:
                        break
                else:
                    pos = len(newconsts)
                    newconsts.append(value)
                newcode[i] = LOAD_CONST
                newcode[i+1] = pos & 0xFF
                newcode[i+2] = pos >> 8
                if verbose:
                    print name, '-->', value
        i += 1
        if opcode >= HAVE_ARGUMENT:
            i += 2

    # Second pass folds tuples of constants and constant attribute lookups
    i = 0
    while i < codelen:

        newtuple = []
        while newcode[i] == LOAD_CONST:
            oparg = newcode[i+1] + (newcode[i+2] << 8)
            newtuple.append(newconsts[oparg])
            i += 3

        opcode = newcode[i]
        if not newtuple:
            i += 1
            if opcode >= HAVE_ARGUMENT:
                i += 2
            continue

        if opcode == LOAD_ATTR:
            obj = newtuple[-1]
            oparg = newcode[i+1] + (newcode[i+2] << 8)
            name = names[oparg]
            try:
                value = getattr(obj, name)
            except AttributeError:
                continue
            deletions = 1

        elif opcode == BUILD_TUPLE:
            oparg = newcode[i+1] + (newcode[i+2] << 8)
            if oparg != len(newtuple):
                continue
            deletions = len(newtuple)
            value = tuple(newtuple)

        else:
            continue

        reljump = deletions * 3
        newcode[i-reljump] = JUMP_FORWARD
        newcode[i-reljump+1] = (reljump-3) & 0xFF
        newcode[i-reljump+2] = (reljump-3) >> 8

        n = len(newconsts)
        newconsts.append(value)
        newcode[i] = LOAD_CONST
        newcode[i+1] = n & 0xFF
        newcode[i+2] = n >> 8
        i += 3
        if verbose:
            print "new folded constant:", value

    codestr = ''.join(map(chr, newcode))
    codeobj = type(co)(co.co_argcount, co.co_nlocals, co.co_stacksize,
                    co.co_flags, codestr, tuple(newconsts), co.co_names,
                    co.co_varnames, co.co_filename, co.co_name,
                    co.co_firstlineno, co.co_lnotab, co.co_freevars,
                    co.co_cellvars)
    return type(f)(codeobj, f.func_globals, f.func_name, f.func_defaults,
                    f.func_closure)

_make_constants = _make_constants(_make_constants) # optimize thyself!

def bind_all(mc, builtin_only=False, stoplist=[],  verbose=False):
    """Recursively apply constant binding to functions in a module or class.

    Use as the last line of the module (after everything is defined, but
    before test code).  In modules that need modifiable globals, set
    builtin_only to True.

    """
    try:
        d = vars(mc)
    except TypeError:
        return
    for k, v in d.items():
        if type(v) is FunctionType:
            newv = _make_constants(v, builtin_only, stoplist,  verbose)
            setattr(mc, k, newv)
        elif type(v) in (type, ClassType):
            bind_all(v, builtin_only, stoplist, verbose)

@_make_constants
def make_constants(builtin_only=False, stoplist=[], verbose=False):
    """ Return a decorator for optimizing global references.

    Replaces global references with their currently defined values.
    If not defined, the dynamic (runtime) global lookup is left undisturbed.
    If builtin_only is True, then only builtins are optimized.
    Variable names in the stoplist are also left undisturbed.
    Also, folds constant attr lookups and tuples of constants.
    If verbose is True, prints each substitution as is occurs

    """
    if type(builtin_only) == type(make_constants):
        raise ValueError("The bind_constants decorator must have arguments.")
    return lambda f: _make_constants(f, builtin_only, stoplist, verbose)

## --------- Example call -----------------------------------------

if __name__ == '__main__':
    import random

    @make_constants(verbose=True)
    def sample(population, k):
        "Choose k unique random elements from a population sequence."
        if not isinstance(population, (list, tuple, str)):
            raise TypeError('Cannot handle type', type(population))
        n = len(population)
        if not 0 <= k <= n:
            raise ValueError, "sample larger than population"
        result = [None] * k
        pool = list(population)
        for i in xrange(k):         # invariant:  non-selected at [0,n-i)
            j = int(random.random() * (n-i))
            result[i] = pool[j]
            pool[j] = pool[n-i-1]   # move non-selected item into vacancy
        return result

    """ Output from the example call:
    list --> <type 'list'>
    tuple --> <type 'tuple'>
    str --> <type 'str'>
    TypeError --> exceptions.TypeError
    type --> <type 'type'>
    len --> <built-in function len>
    ValueError --> exceptions.ValueError
    list --> <type 'list'>
    xrange --> <type 'xrange'>
    int --> <type 'int'>
    random --> <module 'random' from 'C:\PYTHON24\lib\random.pyc'>
    new folded constant: (<type 'list'>, <type 'tuple'>, <type 'str'>)
    new folded constant: <built-in method random of Random object at 0x00A281E8>
    """



# dist.male.first_USCensus1990.lower
male_names = """
James
John
Robert
Michael
William
David
Richard
Charles
Joseph
Thomas
Christopher
Daniel
Paul
Mark
Donald
George
Kenneth
Steven
Edward
Brian
Ronald
Anthony
Kevin
Jason
Matthew
Gary
Timothy
Jose
Larry
Jeffrey
Frank
Scott
Eric
Stephen
Andrew
Raymond
Gregory
Joshua
Jerry
Dennis
Walter
Patrick
Peter
Harold
Douglas
Henry
Carl
Arthur
Ryan
Roger
Joe
Juan
Jack
Albert
Jonathan
Justin
Terry
Gerald
Keith
Samuel
Willie
Ralph
Lawrence
Nicholas
Roy
Benjamin
Bruce
Brandon
Adam
Harry
Fred
Wayne
Billy
Steve
Louis
Jeremy
Aaron
Randy
Howard
Eugene
Carlos
Russell
Bobby
Victor
Martin
Ernest
Phillip
Todd
Jesse
Craig
Alan
Shawn
Clarence
Sean
Philip
Chris
Johnny
Earl
Jimmy
Antonio
Danny
Bryan
Tony
Luis
Mike
Stanley
Leonard
Nathan
Dale
Manuel
Rodney
Curtis
Norman
Allen
Marvin
Vincent
Glenn
Jeffery
Travis
Jeff
Chad
Jacob
Lee
Melvin
Alfred
Kyle
Francis
Bradley
Jesus
Herbert
Frederick
Ray
Joel
Edwin
Don
Eddie
Ricky
Troy
Randall
Barry
Alexander
Bernard
Mario
Leroy
Francisco
Marcus
Micheal
Theodore
Clifford
Miguel
Oscar
Jay
Jim
Tom
Calvin
Alex
Jon
Ronnie
Bill
Lloyd
Tommy
Leon
Derek
Warren
Darrell
Jerome
Floyd
Leo
Alvin
Tim
Wesley
Gordon
Dean
Greg
Jorge
Dustin
Pedro
Derrick
Dan
Lewis
Zachary
Corey
Herman
Maurice
Vernon
Roberto
Clyde
Glen
Hector
Shane
Ricardo
Sam
Rick
Lester
Brent
Ramon
Charlie
Tyler
Gilbert
Gene
Marc
Reginald
Ruben
Brett
Angel
Nathaniel
Rafael
Leslie
Edgar
Milton
Raul
Ben
Chester
Cecil
Duane
Franklin
Andre
Elmer
Brad
Gabriel
Ron
Mitchell
Roland
Arnold
Harvey
Jared
Adrian
Karl
Cory
Claude
Erik
Darryl
Jamie
Neil
Jessie
Christian
Javier
Fernando
Clinton
Ted
Mathew
Tyrone
Darren
Lonnie
Lance
Cody
Julio
Kelly
Kurt
Allan
Nelson
Guy
Clayton
Hugh
Max
Dwayne
Dwight
Armando
Felix
Jimmie
Everett
Jordan
Ian
Wallace
Ken
Bob
Jaime
Casey
Alfredo
Alberto
Dave
Ivan
Johnnie
Sidney
Byron
Julian
Isaac
Morris
Clifton
Willard
Daryl
Ross
Virgil
Andy
Marshall
Salvador
Perry
Kirk
Sergio
Marion
Tracy
Seth
Kent
Terrance
Rene
Eduardo
Terrence
Enrique
Freddie
Wade
Austin
Stuart
Fredrick
Arturo
Alejandro
Jackie
Joey
Nick
Luther
Wendell
Jeremiah
Evan
Julius
Dana
Donnie
Otis
Shannon
Trevor
Oliver
Luke
Homer
Gerard
Doug
Kenny
Hubert
Angelo
Shaun
Lyle
Matt
Lynn
Alfonso
Orlando
Rex
Carlton
Ernesto
Cameron
Neal
Pablo
Lorenzo
Omar
Wilbur
Blake
Grant
Horace
Roderick
Kerry
Abraham
Willis
Rickey
Jean
Ira
Andres
Cesar
Johnathan
Malcolm
Rudolph
Damon
Kelvin
Rudy
Preston
Alton
Archie
Marco
Wm
Pete
Randolph
Garry
Geoffrey
Jonathon
Felipe
Bennie
Gerardo
Ed
Dominic
Robin
Loren
Delbert
Colin
Guillermo
Earnest
Lucas
Benny
Noel
Spencer
Rodolfo
Myron
Edmund
Garrett
Salvatore
Cedric
Lowell
Gregg
Sherman
Wilson
Devin
Sylvester
Kim
Roosevelt
Israel
Jermaine
Forrest
Wilbert
Leland
Simon
Guadalupe
Clark
Irving
Carroll
Bryant
Owen
Rufus
Woodrow
Sammy
Kristopher
Mack
Levi
Marcos
Gustavo
Jake
Lionel
Marty
Taylor
Ellis
Dallas
Gilberto
Clint
Nicolas
Laurence
Ismael
Orville
Drew
Jody
Ervin
Dewey
Al
Wilfred
Josh
Hugo
Ignacio
Caleb
Tomas
Sheldon
Erick
Frankie
Stewart
Doyle
Darrel
Rogelio
Terence
Santiago
Alonzo
Elias
Bert
Elbert
Ramiro
Conrad
Pat
Noah
Grady
Phil
Cornelius
Lamar
Rolando
Clay
Percy
Dexter
Bradford
Merle
Darin
Amos
Terrell
Moses
Irvin
Saul
Roman
Darnell
Randal
Tommie
Timmy
Darrin
Winston
Brendan
Toby
Van
Abel
Dominick
Boyd
Courtney
Jan
Emilio
Elijah
Cary
Domingo
Santos
Aubrey
Emmett
Marlon
Emanuel
Jerald
Edmond
Emil
Dewayne
Will
Otto
Teddy
Reynaldo
Bret
Morgan
Jess
Trent
Humberto
Emmanuel
Stephan
Louie
Vicente
Lamont
Stacy
Garland
Miles
Micah
Efrain
Billie
Logan
Heath
Rodger
Harley
Demetrius
Ethan
Eldon
Rocky
Pierre
Junior
Freddy
Eli
Bryce
Antoine
Robbie
Kendall
Royce
Sterling
Mickey
Chase
Grover
Elton
Cleveland
Dylan
Chuck
Damian
Reuben
Stan
#August
Leonardo
Jasper
Russel
Erwin
Benito
Hans
Monte
Blaine
Ernie
Curt
Quentin
Agustin
Murray
Jamal
Devon
Adolfo
Harrison
Tyson
Burton
Brady
Elliott
Wilfredo
Bart
Jarrod
Vance
Denis
Damien
Joaquin
Harlan
Desmond
Elliot
Darwin
Ashley
Gregorio
Buddy
Xavier
Kermit
Roscoe
Esteban
Anton
Solomon
Scotty
Norbert
Elvin
Williams
Nolan
Carey
Rod
Quinton
Hal
#Brain
Rob
Elwood
Kendrick
Darius
Moises
Son
Marlin
Fidel
Thaddeus
Cliff
Marcel
Ali
Jackson
Raphael
Bryon
Armand
Alvaro
Jeffry
Dane
Joesph
Thurman
Ned
Sammie
Rusty
Michel
Monty
Rory
Fabian
Reggie
Mason
Graham
Kris
Isaiah
Vaughn
Gus
Avery
Loyd
Diego
Alexis
Adolph
Norris
Millard
Rocco
Gonzalo
Derick
Rodrigo
Gerry
Stacey
Carmen
Wiley
Rigoberto
Alphonso
Ty
Shelby
Rickie
Noe
Vern
Bobbie
Reed
Jefferson
Elvis
Bernardo
Mauricio
Hiram
Donovan
Basil
Riley
Ollie
Nickolas
Maynard
Scot
Vince
Quincy
Eddy
Sebastian
Federico
Ulysses
Heriberto
Donnell
Cole
Denny
Davis
Gavin
Emery
Ward
Romeo
Jayson
Dion
Dante
Clement
Coy
Odell
Maxwell
Jarvis
Bruno
Issac
Mary
Dudley
Brock
Sanford
Colby
Carmelo
Barney
Nestor
Hollis
Stefan
Donny
Art
Linwood
Beau
Weldon
Galen
Isidro
Truman
Delmar
Johnathon
Silas
Frederic
Dick
Kirby
Irwin
Cruz
Merlin
Merrill
Charley
Marcelino
Lane
Harris
Cleo
Carlo
Trenton
Kurtis
Hunter
Aurelio
Winfred
Vito
Collin
Denver
Carter
Leonel
Emory
Pasquale
Mohammad
Mariano
Danial
Blair
Landon
Dirk
Branden
Adan
#Numbers
Clair
Buford
German
Bernie
Wilmer
Joan
Emerson
Zachery
Fletcher
Jacques
Errol
Dalton
Monroe
Josue
Dominique
Edwardo
Booker
Wilford
Sonny
Shelton
Carson
Theron
Raymundo
Daren
Tristan
Houston
Robby
Lincoln
Jame
Genaro
Gale
Bennett
Octavio
Cornell
Laverne
Hung
Arron
Antony
Herschel
Alva
Giovanni
Garth
Cyrus
Cyril
Ronny
Stevie
Lon
Freeman
Erin
Duncan
Kennith
Carmine
Augustine
#Young
Erich
Chadwick
Wilburn
Russ
Reid
Myles
Anderson
Morton
Jonas
Forest
Mitchel
Mervin
Zane
Rich
Jamel
Lazaro
Alphonse
Randell
Major
Johnie
Jarrett
Brooks
Ariel
Abdul
Dusty
Luciano
Lindsey
Tracey
Seymour
Scottie
Eugenio
Mohammed
Sandy
Valentin
Chance
Arnulfo
Lucien
Ferdinand
Thad
Ezra
Sydney
Aldo
Rubin
Royal
Mitch
Earle
Abe
Wyatt
Marquis
Lanny
Kareem
Jamar
Boris
Isiah
Emile
Elmo
Aron
Leopoldo
Everette
Josef
Gail
Eloy
Dorian
Rodrick
Reinaldo
Lucio
Jerrod
Weston
Hershel
Barton
Parker
Lemuel
Lavern
Burt
Jules
Gil
Eliseo
Ahmad
Nigel
Efren
Antwan
Alden
Margarito
Coleman
Refugio
Dino
Osvaldo
Les
Deandre
Normand
Kieth
Ivory
Andrea
Trey
Norberto
Napoleon
Jerold
Fritz
Rosendo
Milford
Sang
Deon
Christoper
Alfonzo
Lyman
Josiah
Brant
Wilton
Rico
Jamaal
Dewitt
Carol
Brenton
Yong
Olin
Foster
Faustino
Claudio
Judson
Gino
Edgardo
Berry
Alec
Tanner
Jarred
Donn
Trinidad
Tad
Shirley
Prince
Porfirio
Odis
Maria
Lenard
Chauncey
Chang
Tod
Mel
Marcelo
Kory
Augustus
Keven
Hilario
Bud
Sal
Rosario
Orval
Mauro
Dannie
Zachariah
Olen
Anibal
Milo
Jed
Frances
Thanh
Dillon
Amado
Newton
Connie
Lenny
Tory
Richie
Lupe
Horacio
Brice
Mohamed
Delmer
Dario
Reyes
Dee
Mac
Jonah
Jerrold
Robt
Hank
Sung
Rupert
Rolland
Kenton
Damion
#Chi
Antone
Waldo
Fredric
Bradly
Quinn
Kip
Burl
Walker
Tyree
Jefferey
Ahmed
Willy
Stanford
Oren
Noble
Moshe
Mikel
Enoch
Brendon
Quintin
Jamison
Florencio
Darrick
Tobias
Minh
Hassan
Giuseppe
Demarcus
Cletus
Tyrell
Lyndon
Keenan
Werner
Theo
Geraldo
Lou
Columbus
Chet
Bertram
Markus
Huey
Hilton
Dwain
Donte
Tyron
Omer
Isaias
Hipolito
Fermin
Chung
Adalberto
Valentine
Jamey
Bo
Barrett
Whitney
Teodoro
Mckinley
Maximo
Garfield
Sol
Raleigh
Lawerence
Abram
Rashad
#King
Emmitt
Daron
Chong
Samual
Paris
Otha
Miquel
Lacy
Eusebio
Dong
Domenic
Darron
Buster
Antonia
Wilber
Renato
#Jc
Hoyt
Haywood
Ezekiel
Chas
Florentino
Elroy
Clemente
Arden
Neville
Kelley
Edison
Deshawn
Carrol
Shayne
Nathanial
Jordon
Danilo
Claud
#Val
Sherwood
Raymon
Rayford
Cristobal
Ambrose
Titus
Hyman
Felton
Ezequiel
Erasmo
Stanton
Lonny
#Len
Ike
Milan
Lino
Jarod
Herb
Andreas
Walton
Rhett
Palmer
Jude
Douglass
Cordell
Oswaldo
Ellsworth
Virgilio
Toney
Nathanael
#Del
Britt
Benedict
Mose
Hong
Leigh
Johnson
Isreal
Gayle
Garret
Fausto
#Asa
Arlen
Zack
Warner
Modesto
Francesco
Manual
Jae
Gaylord
Gaston
Filiberto
Deangelo
Michale
Granville
Wes
Malik
Zackary
Tuan
Nicky
Eldridge
Cristopher
Cortez
Antione
Malcom
#Long
Korey
Jospeh
Colton
Waylon
Von
Hosea
Shad
Santo
Rudolf
Rolf
Rey
Renaldo
Marcellus
Lucius
Lesley
Kristofer
Boyce
Benton
#Man
Kasey
Jewell
Hayden
Harland
Arnoldo
Rueben
Leandro
Kraig
Jerrell
Jeromy
Hobert
Cedrick
Arlie
Winford
Wally
Patricia
Luigi
Keneth
Jacinto
Graig
Franklyn
Edmundo
Sid
Porter
Leif
Lauren
Jeramy
Elisha
Buck
Willian
Vincenzo
Shon
Michal
Lynwood
Lindsay
Jewel
Jere
Hai
Elden
Dorsey
Darell
Broderick
Alonso
"""





import csv
from collections import namedtuple
from operator import itemgetter
from path import path

# countrylist.csv take from:
#   http://www.andrewpatton.com/countrylist.html

rename = [
    ('Sort Order',  'order'),
    ('Common Name', 'common_name'),
    ('Formal Name', 'formal_name'),
    ('Type',        'type'),
    ('Sub Type',    'sub_type'),
    ('Sovereignty', 'sovereignty'),
    ('Capital',     'capital'),
    # country codes
    ('ISO 4217 Currency Code',   'currency_code'),
    ('ISO 4217 Currency Name',   'currency_name'),
    ('ITU-T Telephone Code',     'telephone_code'),
    ('ISO 3166-1 2 Letter Code', 'iso_two_letter_code'),
    ('ISO 3166-1 3 Letter Code', 'iso_three_letter_code'),
    ('ISO 3166-1 Number',        'iso_numeric_code'),
    ('IANA Country Code TLD',    'www_country_code'),
]

Country = namedtuple('Country', map(itemgetter(1), rename))

countries = []
with file(path(__file__).dirname() / 'countrylist.csv') as f:
    d = iter(csv.reader(f))
    d.next()  # first row is the fieldnames
    for row in d:
        c = Country(*row)
        countries.append(c)

if __name__ == '__main__':
    for c in countries:
        print c.common_name



"""
The module is a wrapper for the Python Standard Library xmlrpclib, which makes
it very easy to set a timeout on a connecting and communicating with an xmlrpc
server.

usage:
    >>> from timeout_xmlrpclib import Server
    >>> server = Server('http://localhost:8080',timeout=30)
"""

import xmlrpclib, httplib

class TimeoutTransport(xmlrpclib.Transport):
    def make_connection(self, host):
        conn = TimeoutHTTP(host)
        conn.set_timeout(self.timeout)
        return conn

class TimeoutHTTPConnection(httplib.HTTPConnection):
    def connect(self):
         httplib.HTTPConnection.connect(self)
         self.sock.settimeout(self.timeout)

class TimeoutHTTP(httplib.HTTP):
    _connection_class = TimeoutHTTPConnection
    def set_timeout(self, timeout):
         self._conn.timeout = timeout

def Server(url, *args, **kwargs):
    t = TimeoutTransport()
    t.timeout = kwargs.pop('timeout', 20)
    kwargs['transport'] = t
    server = xmlrpclib.Server(url, *args, **kwargs)
    return server



#!/usr/bin/env python

# TODO:
#  * Is there a way to remove the topmost level traceback's which correspond to this script?
#  * add option to run profiler

import sys
sys.path.append('..')

from optparse import OptionParser
parser = OptionParser()
parser.add_option('--coverage',action="store_true", default=False)
parser.add_option('--doctest', action="store_true", default=False)
parser.add_option('--doctest-for', default=None)
parser.add_option('--verbose-doctest', action="store_true", default=False)
parser.add_option('--pm', '--post-mortem', action="store_true", default=False)
parser.add_option('--breakin', action="store_true", default=False)
parser.add_option('-a','--automain', action="store_true", default=False)

# split the argument list at the first item ending with .py
source = [(i+1,f) for i, f in enumerate(sys.argv[1:]) if f.endswith('.py')]

devargs = sys.argv[:source[0][0]]
scriptargs = sys.argv[source[0][0]:]

#print 'devargs:', devargs
#print 'scriptargs:',  scriptargs

(opts, args) = parser.parse_args(devargs)

# hack sys.argv so that it no longer contains this script's options
sys.argv = scriptargs

if opts.coverage:
    from coverage import coverage
    cov = coverage(data_suffix=True, branch=True)
    cov.start()

if opts.doctest or opts.verbose_doctest or opts.doctest_for is not None:
    import doctest, atexit
    if opts.doctest_for is not None:   # XXX: not sure how useful this is
        print 'running doctest for %s only' % opts.doctest_for
        atexit.register(lambda: doctest.run_docstring_examples(eval(opts.doctest_for).__doc__,
                                                               globals(),
                                                               verbose=opts.verbose_doctest))
    else:
        atexit.register(lambda: doctest.testmod(verbose=opts.verbose_doctest))

if opts.pm:
    from arsenal.debug.utils import enable_pm
    enable_pm()

if opts.breakin:
    from arsenal.debug import breakin
    breakin.enable()

# execute the file
execfile(source[0][1])

if opts.automain:
    from arsenal.automain import automain
    automain()



import re

# based on:
#   http://immike.net/blog/2007/04/06/5-regular-expressions-every-web-programmer-should-know/
URL_RE = re.compile("""
(
  # Match the leading part (proto://hostname, or just hostname)
  (
    # http://, https:// or ftp leading part
    (file|ftp|https?)://[-\\w]+(\\.\\w[-\\w]*)+
  |
    # or, try to find a hostname with more specific sub-expression
    (?: [a-z0-9] (?:[-a-z0-9]*[a-z0-9])? \\. )+ # sub domains
    # Now ending .com, etc. For these, require lowercase
    (?: com\\b
        | edu\\b
        | biz\\b
        | gov\\b
        | int\\b
        | info\\b
        | mil\\b
        | net\\b
        | org\\b
        | [a-z][a-z]\\.[a-z][a-z]\\b # two-letter country code
    )
  )

  # Allow an optional port number
  ( : \\d+ )?

  # The rest of the URL is optional, and begins with /
  (
    /
    # The rest are heuristics for what seems to work well
    [^.!,?;"\\'<>()\[\]\{\}\s\x7F-\\xFF]*
    (
      [.!,?]+ [^.!,?;"\\'<>()\\[\\]\{\\}\s\\x7F-\\xFF]+
    )*
  )?
)
""", re.VERBOSE|re.IGNORECASE)


###
# Email validation patterns borrowed from:
#   http://www.regular-expressions.info/email.html

# very very general, probably too general.
RFC2822_RE = re.compile("""(?:[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*|"(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21\x23-\x5b\x5d-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])*")@(?:(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?|\[(?:(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?)\.){3}(?:25[0-5]|2[0-4][0-9]|[01]?[0-9][0-9]?|[a-z0-9-]*[a-z0-9]:(?:[\x01-\x08\x0b\x0c\x0e-\x1f\x21-\x5a\x53-\x7f]|\\[\x01-\x09\x0b\x0c\x0e-\x7f])+)\])""", re.IGNORECASE)

# removing obsolete bracket notation
# EMAIL_I = re.compile("[a-z0-9!#$%&'*+/=?^_`{|}~-]+(?:\.[a-z0-9!#$%&'*+/=?^_`{|}~-]+)*@(?:[a-z0-9](?:[a-z0-9-]*[a-z0-9])?\.)+[a-z0-9](?:[a-z0-9-]*[a-z0-9])?", re.IGNORECASE)


# TODO: add restrictions on email length
#   {local}@{domain}: local 64 characters, domain 255

# refinment of EMAIL-I, it limits country code to 2 letters
EMAIL_RE = re.compile("""
(mailto://)?

[a-z0-9\{\(]                   # startswith alphanum or { or (

[\.a-z0-9\-_/|,]+

[\}\)]?                        # can end with } or )

@                              # crucial!

(?:[a-z0-9]                    # startswith alphanum
   (?:[a-z0-9-]*[a-z0-9])?     # endswith alphanum
   \.                          # the dot in dot com
)+

# the ending .com part
(?:
   com|org|net|gov|mil|biz|info|mobi|name|aero|jobs|museum|edu|[A-Z]{2}
)
""", re.IGNORECASE|re.VERBOSE)

# This pattern is more for validation
EMAIL_STRICT = re.compile('[A-Z0-9._%+-]+@[A-Z0-9.-]+\.(?:com|edu|org|net|gov|mil|biz|info|mobi|name|aero|jobs|museum|[A-Z]{2})', re.IGNORECASE)


DATE_RE = re.compile("""
(
    # optional: day of the week
    (?:
        (?:mon
            |tues?
            |wed(?:nes)?
            |thurs?
            |fri
            |satu?r?
            |sun
        )(?:day|\.?)

        \s* ,? \s*?

    )?

    \s*
    (?:
        \\b
        (?:\\bthe\\b)?
        \s*
        [0-3]?[0-9]
        \s*
        (?:st|nd|rd|th|)
        \s*
        (?: of )?
        \\b
    )?
    \s*

    # mandatory: month (written)

    \\b(?:jan(?:uary)?
        |febr?(?:uary)?
        |mar(?:ch)?
        |apr(?:il)?
        |may
        |june?
        |july?
        |aug(?:ust)?
        |sept?(?:ember)?
        |oct(?:ober)?
        |nov(?:ember)?
        |dec(?:ember)?
    )\\b[\s.,]*

    (?: [0-3][0-9] | [0-9] )?  (?:(?:st|nd|rd|th|)\\b)?   # the word splitter will always keep numbers ord-suffix together

    \s*  (?: of | , | ) \s*

    (?:  [0-9][0-9][0-9][0-9] | [0-9][0-9] )? \\b

)
""", re.VERBOSE|re.IGNORECASE)


if __name__ == '__main__':

    def test_sentence(x, target=''):
        print
        print 'input: ', x
        output = DATE_RE.findall(x)[0]
        print 'output:', output
        print 'target:', target
        if target:
            assert target.strip() == output.strip()

    test_sentence('I was born on Monday, March of 1986.',  'Monday, March of 1986')
    test_sentence('I was born on Monday, March 18, 1986.', 'Monday, March 18, 1986')
    test_sentence('I was born on March 18 1986 .',         'March 18 1986')
    test_sentence('I was born on Mon. March 18, 86 .',     'Mon. March 18, 86')
    test_sentence('I was born on Mon. March 1, 86 .',      'Mon. March 1, 86')
    test_sentence('I was born on March 18, 86 .',          'March 18, 86')
    test_sentence('I was born on March, 86 .',             'March, 86')
    test_sentence('I was born on March 86 .',              'March 86')
    test_sentence('I was born on Mon. March, 1986 .',      'Mon. March, 1986')
    test_sentence('11th February 1990 , ',                 '11th February 1990')
    test_sentence('the 11th of February , 1990 , ',        'the 11th of February , 1990')
    test_sentence('February, 1990 , ',                     'February, 1990')
    test_sentence('Monday the 3rd of February, 1990 , ',   'Monday the 3rd of February, 1990')
    test_sentence('Mon. the 3rd of February, 1990 , ',     'Mon. the 3rd of February, 1990')
    test_sentence('Mon. 3rd of February, 1990 , ',         'Mon. 3rd of February, 1990')
    test_sentence('Mon. 30th of February 1990 ',           'Mon. 30th of February 1990')
    test_sentence('th February 1990 , ',                   'February 1990')
